
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python Fintech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\x88*\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b"\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00H*\x00\x00\x00\x00\x00\x00\xe3' \x8ek\x98\\\xdc \x13\xe9\n\x10,\xd8\x01\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85"
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=\xbbB\x0b\xeb\xca\x83\xe9\xad\x8cB\xa1\x1d\n\xc9c\x9dZ\x894\xd8l\xeat\x82\xe0\xbdR\xeb\xc85\x817@\xfe5\xdfZ\xa5\xc1\xf1\x9b\xb7\xa3\xe3\x03\xe5\xc5'
        b'\x86=>\xa1\x89\x12\xf4:\xd9#\xd4\x01.w\x99t\x13a\x82\x00\xcd:\x98b\x11\t\xdb\xb2"\n\xe8)\\\xdb\xe1\x1e\x9bm\xff\rpV\xa5\xf7?\xe1\x85y\xc6\xe8\x87h\x7f\x9d\xcf\xfe\xe94\xd9\xc8+{\xfb\xf2'
        b"v\xab\x9bcT\xcdG\x81\x82\xd68\xf3\xff\x0c>\x1f\xb6EmXZ\xea\xdf\x9caw\xcc\x8e[G\x18\x1d\xbd\x1c\x91\x84\xab\xf9u\x93\xa86\x16\xf8\xa7Xuf%\xe3f\x80v'CW1>\xf2\\\x88\xda\x12\xf6"
        b'\x96\xc0\x07T\xbc\xb9\x08e\xb9\xa4\x18\x85l\xfbo\x95P\xa9\xf1o\xd6F_l\xb4(\t\x84\x84\xa8\xb3J\x0f\x13\x19*\x99e\xfc\xf6\x7f|b\x17#X\xf8]w\xcd\xb6\xc9\x9a\x13\x18\x8aFY:n[\\\x99R'
        b'\xe9#\xc2\xdf\x1b\x8aO\xe0\xd3\xc2 s\x9b{\x8cw\x021eW\x15Y"\xc0&\x040\xaeO\x8fH\x9d\x81G\x0f3\xbc\x8c\xfb\x19\xaec\x9cr\\\xc7 \x88\xc5]\x0b\x8a\xe9\xe8\x94\xde\x18T%\x81\xe4\xe0\x9c0'
        b'\xc2\x147\xd2\xd6Jj\xa9\xf2\xb8\xe9>\xb5z\xa8[\x96\xa3\xa8\x98[\xae\x16\xa3\xc9\xed/\'\x01\xb0\xbe\xc8\xc2\x83.\x01\xe7\xe1\xdc!e\xdf\x81pw\xfd3\xb0\x01%"~XH@\x1a\x92c\xe7\x03\x8e\xd7\xc6g'
        b'\xebo\xe6\xe0\xc0\xc5\xc4\x9f\xacl%\x8c\x05\xf4`\xfd\xe6UQ\xf6!5wX\xbb\n\xeb\x8f\r\\\xe4\xe6\xffA\xd2\x0bZRp\xde\xdc\x8d\xd8\x9c\x0b;\xe5\x84\xd6\xcc\xcf-x\x97.\xc2\r\xad\x8e4\xff\xf3f\xd5'
        b'\x05\xd5L\xb8A,y\xfc\x028\x03\r\xd9\xb9\xc5\x13\xd64\x13>\xe1X\xb7\x7fU\x1dJ\xf9\xb5,\xa8\xb0\xea\xcaB\x96U\xb98\\4F=\x98e\xe1\xa4z W\x83\xf6gc\xea\xa0\x12=\x80\x18C\\\xe1\x16'
        b")\xb9$\xc8\x90\xf6\xb2;#\x88z-\xa6\x15\x0b\xeeVZ@\x11\xe1\x8e\xc1\xe5\xef\x9c\x1a\x02\xcf\\\xf8'\xacb\x9a)\xc5\xbd\xafn\xeb~\xdcX\x87sc\x83a/\x17a\x90B,\xfb\xad\x12!\xc1\xc4-\xcd\x80"
        b'\xc8\xd4\xe3pW\x99\xde\xb9\x11O\xb9:\xf39\x8b\xaa\x97\x95\xc7\x90\xa3\x94*na\x02\x8c\xdcgS\xb5)\x9b\x86\xb0S3:*\x01\\\x93:)[y\x8dz\x80\xa9e\xb2\xce\xa2@\x1d\x0e\xec*u\xeb6bT'
        b'Y\x9f\xf8\x82\xd8\x0edDK7\x96\xf1\xa3\xf1\xc9\xb2Rs@\x037[<Ir2=\xc1A\xee\xc5\x0099:*\xafZ\xc9$}\x80\x11#\x9c\x8a\x94\xe77\xdb\x05\xd9\xe7\xf5D|>\x84\x1d$\xbce.\xa8'
        b'\xcd\x9d\xf0e\xfd\x8f\xbcOP")\xaa\xf6\x94\xfd\xda\xfb\x02\x9eS)nz\xc5\xf3Oc\x07\xae\xd5^\x8b\xec\x96./\xaa\xe6\x8b\xd0\xc4\x06\x10\xd2\xa7\xcb+4l \xebp\xaf\xb9V\x194\xf3E\x1e~\xb08\xcd'
        b'Q\xeft7XDR0\xfe\xd2\x8a\xdd8\xe9nz=\xb7?Z\x0bD"M\x17\x84\x02\x12\xca\xece\xe8KS\x1e\x03\xe2\x8a\xe7E\xd2\xa6F\x83<\xa0\xaeI/\x9d\xbbBB |\x16T*\x1beaGKa'
        b'\x12\xb4\x05\x0f\xc8\xfe\x07K\xe5x/#d\x13\x13\x9f?v~\x07}\x8d\x99e\xa55@!\xb3D.\x80\xf7o\xc0\x07\x9c\xdaI\xf7\x9fDfqT\xf3N\xe8m\xe0E\x9c\xa8)}q\xa1\xbb\x9bc\x9e\x88\x1f9'
        b'\x1f]\x0cI\xf5\xa1~A\x91\xcd\xf8\xef\xa6\xa7\x06Uu\x11\xdd\\\xce\x9e6\xf0\xb1\x88\xfaV\x92\xd65\xd0\xd0\xa7\xe6\x9b\xaa\x06\x1a\xdcV\r\xf7\xe7\xa1\x0c4V8\x9b\x05\x8c\x9f\x8e\xe3\x93\x8a\xb7\x1fF\x7f8\x04\x89'
        b'l\xa5\xd6h)Y\xe1\x93x\xf4\'3~#*~G\x05yk:vF\xdb\xfd\xddVR\x94\xbc\xdd\x9e\x805\xde7\x84\xb3D\xe5\xdfO\xee\x1c\x9e\x01\x81\xa7\x8f\xe8\xf7\xc4\xbf)\x95\xc3c\x88\xa4c\x86\xbb"\xe0'
        b'\xcf&h\x9ci&\xdbop\xae\x0f\x01\x19\x18h\x01\xe5\xba\x17V7G.\xfaz\x914\xd1\xe1\xc4]m\xa0\xcc\xae7<\xd6W\xb4\xac\x11\x13,(\xcc\xa57\xe9a\x87\xc6e\xd5m\xce\xf0\x9ft2\x9f\xa2\xbb\xfb'
        b'\xeb\x93\x0c\xbe\xb2\xe9\x8e\x1e~\xef\x9ap&\xd7\x12\\L\xa6\x9c\x15\xd1\xe5tG\xe8{\xc3g\x99\xef\xcd\xa8U\xf0\xcdm\x9d\x7f\xda\xea\xbel\xad\xa2\xfdV\xe0"\x05\x04L<\xb0\xadvd\xd4\xcc}x\xf7F{\x9f'
        b's=\x8bY\xc0e>\x13\x98,\xc6\x99\xa0$\xc1 {\xb9\xf7P\xb3\x84\xef\x9e\x81\xa3\x8d\xb2\xe6"T\xde\xa0\xeb\xb6a{4\xcc\x91\xbc\xc6\xae\xfdi\xf7\xe2\xe8\xca\xde\x0b\x91F46\xc0\x8bE\xa1\xaa\x95\x01]\x10'
        b'C\x0f\xffT\x9d\x19\x0f\x92\xd7\xd4\x1a\xe5)a*\x85\xea})\x8a\xc1\x0bq\xebQi#\r\xffo\xbe\x1c\xe7\x0c\x98\xc8(\x11?\x12X\xca{\xc3\xd2\xf3\xf6M\x88P\xa2\x9a\xbaC\xbc\xc7{ar\x95\xdf\x122\x9c'
        b'\x94\xeeV\xc4f\xf3\xd5@&\xd3\xber\xb0\xa2\xf2\x9c\xee:\xe4\x05\xcc\xd5\xf4\x977\xd2\xe3\x86\x830jF\xac\x90eDc!\xb6\xd7F\x85\x99\xea\xcf\xe1\xea\x1a\xab\xeeP\x9f;\xb56/\x9d\\=\xc4\xbd\xc3\xd7\xfa'
        b'5\x84z\x86\x85\x13;\x19\x8d\xdd6\x01z\x19qg\xa94\xd9]R\xdfp<\x08C\xb0Fn\xd1\xf7\xc2 u\xc4\xcd\xc7\x1f\x9b\xce\x06,!F\x8f\x8b\xbb\x91d\x98\xdc\x00\x8anE&\xb2\xaf\x9f\xaer\xcf\x91\x08'
        b'2\xe3\xfaW\x1fk\x9cyQq\xb4F\x18M\x10\xe2\xc2Y\xa9\xca\x04\xf7\xf2\xfaE\xe5\x135\xc5\xa2\xaa<F\xa2UC\xaf\\\x95y\x94Y\xb1\x9c\x84\xc3\x04\xde\x0c\xf4\x0ca\xcc0Gg\x07\x06V\xf4,\xff!"'
        b'wD\xea\xd6\x94\xbd\xf5f\x94U\xf3\xaf\x82\xb6C\xf8\x83\xad*\xdc\xc1\x9b\xcc\x91\x89({\xe8\xc2\xfd\xb0\xb6k\x9b\x07\xefd\xfcK\xc2<\x99i79v \xe0\x01V\xab\x80=\x81Z<QB\xbd\xed\xf4\xc7\xfb7'
        b'\xdfv}d"\xcc\x0f\x00\x07\x1d\xd1zlm\xfb\xe8\x04Do\xe4e+^^\xf0\x16*!\xb0\x91\xe5j\xd4\tM\xe3\r\xed\xd7`w\x82\xb0\xbe(\x95i\x17\xb2\x8e\x15\xc1\xdf`\xfeH\x9d\xf5\xd8$mB\xb2\x8f'
        b'\x1e\x1c\x1c@\x16\x03\x1a\xe3o\x06g\xa0\xf6~\xb0S]NW\x8c\xd2`6oc\x00\n\xe2\xf0Y\xd7)c|\xffZ`m\x0f\xee\x93\x8d\xbdhC\x9c8\x1a6\xd5\xdeN\x8d\x07=\xaf\xe0x\xb3F\x80ha\x05'
        b'\x9c\x18\xd7\xa1%\xaf\x91\xda\xc4\xa2\xbfa\xb3\xea\xa7\xe0\xdc\x8cb9\xfa\xde\x83\xc2\xb3\x04\xf9\xec$\xac<\xf4\x1b\xd6\x1e\xb3\xe62P:\x06^f\x8c\xfd\x07Uw\x9aS\xf4W\t\x9f\xec\x83SA\xad\x11@\xad\x83\xe1'
        b'g{\x00\xa2\x8ek\xa0V\x94\xc4V\x08\x14\xbdj\x13\x95k\xa7\xa7t\xaa1\xd4\x9b\x86|\x86\xa1:\xb0\x17\x16*La\x1d\xa8$\xb1\xe3\xb4\xbb\xb6\r\xb3V\xe3\x8c\xdb\xdek\xdc\xc2X7\xe6\xe3_\xed\x93\x0e\x00\x00'
        b'\x03j\xbc\n\xee\x83\xc1\xc4\xf2|\xd0\xf9\xae4r\xc2\xeen?$`\xb4\xa1\x1ep\x98\xde\xda]<\x89\xbc\xc4\xa3F\xf3\xdaE8+\xab\x93\xbe\xcc[\x02yL\xe4\x7f/\xfd\xdd\x82\x86N\x0c\xe8`\xbf1\xc3\xeb\xdc'
        b'\xff\xc9;IU\xa9\xa9\x14\xadw\xbcC\x9br\xbc\xf7\xdfZ\xd9M\xe5\xea\x98?^\x91\xf5L\x90\xc6,I\xec9\x85n\x1cw\xddO&2\xee-SG\x99\x977\x0cb\xf0\x97\x9f\xef g\x04k\xfcq\x1b{X'
        b'\t\xee\xc3\xc0\xad!\xb2\xf9\xf5\xa7f\xc7`\x9d\xd4\xa6\x15\xeb\xcd\xdc\xef6`\xfb\xc7\xf0\x10\xfeY5\x88\xfe\n\xc6\x14\x902\x05\xdd\x0c\xc0(\x8f\xa1\x8b\xd9\xcb\xbc7\x9d\xb8\xf2`<\xbd\x9d!u\x15\xae\x01\x90.\xf4'
        b'\xe9R\xf5Z\xbcO\x81\xf4\xe2;\xfe \xfb\xac\x7f}nO%\xd3\xa0\xc7\x96\x93\x95\x96\x19\xef\xa3\xa8[\xb8\xdeCsRF\x15a/F\x96\xa1E\xc8P\xd6k\xbd,\xa1C\xe4DJ\xe0+\x1e\xb9\xc2\x05\xc3\x18\xe0'
        b'\x9a\x8eI\xe3\xbe\x1c<F{\x88\n\x961\x05\xad\xf6\xe6\xcc\xeb2\x10\xe3\x1bWj\x9a\xdb3\x0f\xc4PO\xd9\xe0\xad\x98k`\xd8\xe7\x08\xab\x19\x99\xb4m\x8e\x8a\xf7\xb2H\xad\xe4o\xdeb!\xc6\x9c\xe4 \x85=Y'
        b'D\x8aQ\xec\xfc*k\xf8>(#\xa4\xe3\xce\xf3F\xb7\x95A&\r:\xa2;\xef|\xcf!\x97O\x1c\xc88_\xf6\x16aB\x87\x0c\xb1\x83ED\n\xbd@2\x13\x0c\xa4\xe0\xa1\xa1\xecVQ\xbb+\xa4Q\xc9g\x80'
        b'\xdf\xfa_\x06 U\x8d\x05\xd5\xacJX\xd7\xb8\xe2\x1f\x87 \x14\xe6\xd9*\xbe-@T\x00\\y\xb7%W\x86\x99\xf1|\x15\x82\xa0_BS\xdfc\xb7sB)\xeb\xe2FxT\xd7\x96\x06\x1fp\xd4.\x0eK\xa7\xfb'
        b'G4\x9d6\x84\xd4\xc3>\x1f\x82\xdb\xb3u\xbcS\xa7\xec\xb9SF\xb2?\x1dJ\xa6U\xe9\xa9\x8e?\xae\x12\xeb\xea4\xbae\x98\xf0N\x99\x8aS\x01\x19\xab\xad\xe7\x9b\x7f\x1f\xcf\xd3LLN\x15\xd2B[j\x8cnH'
        b"\xdf\r2\xfe\xe7&74W{jF\n\x1aI\xac\x8eC\x93\xa3ZB\xb9-M\xc1\xff\xc4\x19\xcc'\xfa\x9f&h\xf0\xf6\xc0\td\xd9\x03\x81s\x83\x97\xee\xdd\x9aO\xa2k\x95\x02\xac5\x8c,\xef\x16\x8d$\xd9U"
        b'\xbc\xb7zO\xdc\xe4\xcb\x11<8\x1acr\xa40\xd5\xbf\xee\xc2m\x08\\p\xf4q\xb3H\xdf\xb9\x95x\xc7]\x0eB\xf7^\xbd\xda#\x8f\xe4\xbb\xb6\x9f\xc1\x11`\xe3h\x8bJ\xa7\xd8\x00%\xbc\x14\xa2\x14!\x82\x8fW'
        b'\xeb\xado\x17\xbfW\x17m\x88\x7f\x8b\x95\xee\xec\x164\x15\xdd\x9a!\xe9\x108NHK\xed\xcdO*\xe4\x8b\x0e!<F\x1c:4%&\x7f\xdf\x7f\x11\xe5\xf0\xb2Y\xf3\xf8\x9c\xee\xa4\\=)\x94q\x8c\x93\xc4\xf9\xb9'
        b'\xa1?$\\\x15\x8f\x02h\xcd\tPT\xb3\xe5\x8a\xde\x84\x14`\xc3\xa29\xd0lw\xdaOj\xc1\xf9\xa6\xed\x08\x9f\xe4Yml\xa92\xae\x87\x1c\xf2\xa5\n"\xec\xff\xea\x88&\xb3\xb4Tz\xa4\xb9\xc8\xf4}\xcb1\x92'
        b'\x05XN6\x05\x95\xdd\x02\x81\x85\x15\x99\x92\xc9\xe8#\xc1\xd0\xe2I\xaaC\xf7\xe4\xfa\xa5\xd3yf\xa6\x80\xa9\x1d\x93\x00\xc1\xd6\xfb\x7f\xa39\xc1p\xdc\x9f\x83_m\x1f\x98\x07\x8et\xae\xc6\xb1[C\xa2\xfb\x9c\xdc)F'
        b'.\x15\x07\x9b\xe3\xc4\xcdCn+\x86{\xfc$EU\xb0\xb7\x957\xec\xda\x9c\x9d\xb0TH\xad8\xe9\xc6?\x99\x16Hy\xb5\xfe\xa0\xac6\xef m\xb4\xc1Mg\\\xf5\xb2\xae[4\xef\xad\x1a\xbed\x01\x1c\xd0\xef\xf2'
        b'\xd2`\x14"S\xff\x97%\xf5\xb8e\x10\x0f\xce\xb6B\xa5:\x19\x0f\xeb\x85\x1c\xdb\xf1\xff\x8a\x0b\xb1\xb0\xd6\x0c\x8c\xb3\xeb\xa8 \\\x9ee]\x1e\xc0\xb5\xccS\xd6\xbf!\x0b\xe4a\xde\x19\xc9\xcf\xae\x01\xf4T\xbc5\x8c\xd3'
        b'\x86\xb8\x13\xc1\xbdO#kc=B\n#\x14\n\x97\xb2\x9b\x125p$\xddg!\xa5F&\xb8s\xf3dr\x10\x1fZ<\xf7\x01\x06\xb7\xb0Q,\xdd;l_\xfc`j^p+\x08M\x01\xd5\x0c\xb1W\x94\xb6\x97'
        b'\x92\xa3\x0e\xd0q4.\x91\xec\xa2j\xe2\xa2\xa9\xb3\xb8\xf0\xce\x9d\xb9\xd3\xb7\xf5?\x94\x07/\xe8>\xb0\xb4\x7f\x85\x95mH\xfd\xb3\xd5\xdb\x9c\x14\xf2\x8e3gM\xbe\xe8\xfd\xd5e\x16\x84b)4\xddo\xb1\xc8\xb0A\xbb'
        b'\xa0\xea0\x01i_\xfck\xae\x10w&\x80\x0c\xa9\xb6\x9a\xb9n\xa8\xedxr\xd1\xcfk+\x0f\xe6lP\x84v\xbb\xcfQ-\x1f\xd0{\xfb\xb3mR\xf5004\xa9\x1b\x87\xa9\xb1\x93r\x02\xb9&\x14\x0e\x04\x04*\xc4'
        b'\x1e\xd6nE8\xf2\x87\xcf\xd2nW@\xd3\x86Kj\x130\x07\xe4\xb7\x82\xa7\xc7\x9df\xeb\xfbHN\x95\xc1e\x15\xdbn\xe8\x88\x84\xde\x18\x948\xa2L\xb5\xc3q\xcah\x1a\xd1=\x99\x107?\xbcFdx\nz\x04'
        b"\xa4\xa6\x06|\xf5\x1b4\xf8\x18\x9d^\xb9&>v\xeb\xab+'v$\xce\x1d\xb2]h\x90@\xd8Pr\xc8s\x84j\x10\xf1T\xfb2u\x0b\xb1\xff~\xe1e1<\xa1p\xb0\xe5B\xd3\xc6Vp:\x83o\x89\xa2\xd1"
        b'\xcc\xbc6\xdb\x0b\xab]\xf7\x9a\x89\xd0\xf5\xaf\xa3>Ne!2u\xcb?\xd71~\xfa\x0e\xa3Ek#\x8aC=\xc1C\x02\x8b\xd0\x95\xc3I\xf9\xab\x96|n\x07\xa0\x0e\xabO\xa8\x92\xd4\xec<\xbf~\xc7\x99<\xfd\xe0'
        b'\xb4\xcb\x8b\xe9\xa2\xa3\xa2\xb2\xc0m\xaboQD\xb5k\xd2Z\xa95\xf1\x1a[\xb9X\tG\xa5n\x94\x85\xb9H\x100\x10\xcc\xc0n_9\xa4u\x93\xeew\xf7R"_Vy\x0e\xbd\x03\x8e\x04,\x14u\xf9|T\x01'
        b'h\\\xc5\xbc*\xb01k\xf4\xbc\x89A\x90\x97\xc9\xae\x96)T\x10M\x8bIa\xe1\xba7)\x07\xdb\x1f\xb2\xbfa\xa6\xa5\xac\x11b\xcd\x01\x13?\xf1Wr\xba\x00\x92\xd4\x04\x02\xa9\t\xa7\xfc\xa7\x1e\x91n\x10\x1a\xce\x10'
        b"\xce\xb5\xe2\xea\xe7\th\x88\x1bKb\x82Xu\xa6\xf8!U\xa9\xeb\xe1X\x16\r\x10\x85d\x1c\xb0\xd4\x92\xa7\x15C\xa1\xd09@\x9b\xda\x8a\x8a\x0e=8\xdd2`\xa9\r\x01By\xe0'\xf0\xbb\xcb~\xfbG\xe3\xa0\x80"
        b'\x04nXq\x99\x83\xb0s\xab\xed\xb4A\x08\x03\x1f\x0f\xe7\xb0]\xac\\\xd2\xd6b8\xc3$\x89#]\xd4p\xe1\x08^\xe8&\xccs<\xe7i\xbb1T|9\x87\xdf\xbd\xd2"?\x16\xbb\xb7X\xf0\x1e*\x92\xcc\xbfW'
        b"\xf2\xdd\xa34\xc8h\xafLs\nJv\xedI\xe1J\xe8\x90\xaf\xb0\xf6\x7f\x02'\x95z\xb1\x9e\xfd\x96\x99Ogc\xcd\x0e\xc5\xaey\xb6\xa2\x8c\xec\xedfz\x9aA5^t_+\xad\xc5\x07ya\xcb\xe2\x1e\xfa=\x83"
        b'>\x93\xc2\x88\xf2\\\xc1\x8e\xe8\xbb\x81\\LL\x10\xb0p\xd3\xd9\x17e*\x1bK\xdc&z9\xcd!\xe8\xa7\x98\x04\xcb\xb5(tG\xac#\x93H\x0eTb\xd4\x08}\xe8n\xee*\xa5FV\x8a\xdb\xa9\xbb\xd5\xcf\xb6v'
        b'\x87?\x969<\xf7\xe9\xdd\xca\xf0\xe0\xf0\xef\x86x\x8cj\x97\x9eU\x85\x14\xa13\x9byz\x94\x8b\xa7t.\xea\xbc\xc5\xbc\x01N\x8d \xfd\xf3H0\xc2-\xdb\xaf\x80\xab\xd9\xf0VKO\xceI\x0c\x9d\xfa\x89{[\x99'
        b'*\x1d\x7f\xc8 g\x00n\xdd\xdfl\xb9\xee\x00fY\xd2\xda\x06M\xe3\x81}{k\nc\xa5\x15\x05i\x7fK\xce\xd79\x1aQ(K\x9b\x18\x1f(4\xa9\x14 \xf3\x9c\xe6^\xb2\t\x1f.\x8d\xe0\xa4/\x1aeO0'
        b'\xc6\x9d\x01\x1e\xb2z\xd7\x1b\x18\xc9\xce\xbc;\x85\x9e\xf1l\xb3\x86\xb2\xb1\xe99e2\x0f\xa4F@u\xdc\x88\xac\xb983FZQ\xf5P$0\x02\xdd\x1e_\x91\xb8\x11\x08\xae\xf821\x9a\xe5\n\xd3\x1c\x8f\xd7P\t'
        b'x\xd6\xdc\x9c\xf56\xcd\xb55\xa3W\x03\xbd6k\x95\x98\xdd\xd2D\x0fB\n8\x007\xcb\xdf\xfc\x92\xd8\xf0\xb6\xeeb\xa5\x9b\xb92\x02=\xc9|\xaf\xd96\x84\xb1\xc2\xc5\xf5\x1a\xcc:v\x98\xde\xab\x8e\xcd G0\x96'
        b'\xb7\xcf\x9d>\x93UB\xe0P\xcf\xe1\xe9\x04\xce\x9a\x9d\x8b\x86\xcb\xc3\x8b\xaa8\xb8\x9af\xcd\xbd.\xa9\x02\x153_K\x0e\xe3X\xc6\xa9s\xb3\xe9\x15y\xc4\xaaYow`\xcb]\t\xa1\x17H\xc5\xdf\xc0\xcd\xd0J\xd3'
        b'\xf6\x1b\xed0\x97?*1ec\xd9|*.\x03\xe8E\xd2d@\xa9\x98k\x13\x98\x99\xd2-\x06KOI}\xd0\x87\xb8/J\xe4<[\xb8\x84\xe5_\xeb\x94\xbe\xf61\xb3\xd9/\x81\xe7 Lu\xf6\nco\xb1P'
        b"[\x1e\xc67\xe0\x18'\xc4\x17\xb3V\x86\xfa\tE\x9d\xadV{\xe25s\xa8\x84\xcaG\xdd\x0f\xf9%\x928\x0eX\xb0Qh+P\xc9\n\xcc\xdb\xb1\x0b}\x7f\x17\xdf\x9ce\xe0\x89\x86\xeb\x17&\x86\x0f\xf1w\xc23b"
        b'\xbc\x9e\x9c\x1b\xcdS\xb8\xb1\xab\x95\x1e6\xf6P\xf4B\xfdm\x85\x9aw\x90!\xb6\x08:4\xc73\x03\xe3\x9bK{\xd1C\x04\x89}\xc0\xb1\xcf=\x1b6\xd06\x16\xc9JK\x82\xe2{5d\xb7\xf1\xb1\xefF\x94\x12_'
        b'\xf1S\x92\xbbV\x9f,\x08fZr\xc2[J\x1b\x00\xf1P\x1d\xc35\x94\xae\xcc\x81\x92}\x91\xed\x1b\xfb\xb9y\x0c\xad\x90\x97 ^}(5\xf9\xab\r\xca\x0f\xb2\x13\x1737\xdf\x8b\xab\xe30\xcc7\x07S\xed\xf2r'
        b'\x0e\xceWY0N\r\xd7\x15\xf2\xe3\x84\x9d\x1e0\xbcvo\x1f\x9bK\x8a\x8b\xc1c\xf8G\xd8\x9b\xdb\x985\xfb\xce\xaf\xa0@\xba\xb5_\xe2\xab\xbeHa\xd3`\x07%\xb2\x0e\xde\x8b\xcb=\x1b\xa8\xd5H\x01\xda\xd1\x11\xf4'
        b'\x90X>q\xdc>\xb9\xf6\x87\xfa#\x98"x\xc1ZQJw\xa5;\xed\xb3\xab\xf1\xb6\xec\x0f\xa9\x0fD\x02a\xab\xe9\x05"\xbd\xf9f\xa1\xef\xac7\x16E\x92qWd\x06\xa8\xf0\xcaV\xccD\x1du5\xe6\xd7\xdfg'
        b'O\x1eq\xe5\xf6@x\xbelT\xa4\x1a\xecx\xa2/,\xcf\xb8\xeb\x05\xec\xb8\x90\xd3\xb0\x14\xff\x82\x13\xe0\xe8\xdf\xcb\xed\xc2\xd4\\ \x13\xd0\xcb-\xa9\xc1\xbb\xbe\xbc\xac\xce\xba\xfa\xcb%CV\x03\x12\xa6Z\x96\xc2\xe4\x9b'
        b'\x90\xbd\x89C_i\xd5s\xb6\xae\x0fZ\x12\xea\xcbS\xf6\xa1\x0e~U\r#"/\xc3A\r\x8eK\x94D\xf2\x1d`\xaa\xa1\x01\x13\x0c\xab\xa7\xc7\x9arf\x19\x1c\xf7* {\xc9\xbf^!\xe4\xf6\x85\x8c\xb1R&\xe4'
        b'\xfe\x7fW\xc4\xf6\xf4;\x1f\xf4\x0b\x84>YH\xa5|V;E\x0b3sVG?vC\xafM\xce\xc2\xad [m8\x99G\x15#7g\x91\x9f\xb2Q\x1e\x9b\xd7\xef#y8^\xb1\x13\x9d<\x86\xab\x8d\x99\xc8?'
        b"\x0e\x84\xbb\x03\x81\x84D\xe4F1\x16{VFW\xf4W\xf7\xd1\xbd7\xf2Y\xdd6^\xc7\xfc\x9e\x15\x15\xee'\x91\xd4(\xeb\xb7\x94\xc3+?\xdc\x00k_\x8f$_\xfc\x87x#\xb2\xe0\xec\xb9UQ\x18j\xd7'+"
        b'\xb0\xee\xb2\xa4\x14J\xa9\xa4T\xd7\xaa\x12\xc5c\xa0o\x9dh_@\xbd^\x81A\xe3\xa2\xc4\x17\x08\x91\x93\xee\xc7r\xf4\xba\xea\xf0\xd2\xcc\x82l\x97\xe8\xdbk\xcc\xb3\xe5$k\xacN\xe5\xc3/xZW{~\xe6,r'
        b'\xa4\xa70\x01V\xf6\xb5\xc7\x00p\x8a[\xd0:t\x18\xe2\x9e\xeb\x16\xbc\xb4d\x9eS\xf3-\x9c\xf5\x95\xf8%4\rX\x1f\xce3c\x0e\xab\xbfY\xber*t\x82\t\xc3-N4-@\x80p\x0c\xaa\xaa>J\xee\xd1'
        b'i\x00\x1cP\x82\x02\xf9($\xc9\xc1\x98\r\x7fd\x9d\x9db\xe4\xedi\xbc!\x97\xd63w\xf8\xea\xe3\x00k_\x83.\xca\x13NT#\xac\x1c\x8c\xbc\xe2!\n\x8f\xe2\xdb&\xa6\xacf\x15\x0bU\x7f5\xa0O\xbd\xb6\xc4'
        b"F\xff\x95\xec\xab6\xf5\xe4S\xb0\xecR~@\x87o\xf0\x85\xf12\x1e\x80B\xd2\x1c'\x11\x1bN'r\xe3\xa0/U#G\xe6\xc0\xb0N\xbf\xd5\x03L2Ul \x93\xa2\x12z\xc6\x95\xd7\x19\x9e\xb99\xb4\xb0l\xc5"
        b"N+\x99\xc4\xc6\xccC\x83])\x8c\xca#\xa8\xa3\xa9U\xc9VX\x9b9\xd4\xa1\xae\xa2\xe9C\xe4\x98\x13\x1e\xbf\x81\xdc\xb0\xb1[\x1a\xf6\xa5\xbc\x17\xbaN+WA\x8d\xd7\xcd\x02\x93\x9e\r=T|\xed\xd6V'\xa5\xa9"
        b"\xb9\xf7\xfa{\xa7v\xc7\x928\xec\xb2\x1f19\x9f\xb7:\x1eC\x87\xb4@3A8Z\xa8\xd9\xe0(['i\x11\x92\x9e\xad\xa9\xa3\xcec\xde\xf0\xd6;0\xc7\x15O\xe2\xea%\xf8\xd2\xd0<\xc4!\xd7\xf3\xb2\x18\x07\x87"
        b'\xda=\xbb\x86\x1f~G\xfc\x91\x92]\x98\x14A\xe1\x9f\xa3\xdb\x8b\xc3%\x8f\x02\xce\x19:\x85\xb4BQZ0\xe2\xaa\xabu\xe4@A\xdb\xed\x94\xact\xc8\xd3A\xd7j\x1d\xc4~"\xe6\x9b\x1d6\x14!\xdd_\x97\xb7X'
        b"{\xb9^\xdf\xf2%\x8d\xd2\xd5\x9ejj\rq\xfc\xc0mes\x00\xf3ZR\xc5hi\r\xdf*\xf3t+\xa4\xf7Bj\xb7\x00/v\xe4\x9b\xa9:\xcd)\x087iD\xd9'Cd\xd0i[8\x85>\x86\x8b\xa4\xd7"
        b'\xccfX<\x1eI\x1f\xc7\xd9\xfa\xfb\x8fl\x16\xa7v\xb0\xafP.\x9fA\xc1\x7f\x0c\xbfQ5\x98\xa8\x12K\xa7}\xa9u\xf0\xb3\xf8\x80\xb0\xd3\xd8%\xaf2\x18L\xe0\xd6\x1f\x07\x16#\xbd\xc0\x87\xe1\x8c\xe70y8w'
        b"!x \xa5\x16\x0b\x9b|\xadr\xbb)\x0e|J\xbf`\x96A\xa3\xc0\xf0\x16\x07\xed\xd7'\x13\xf6\x7f\xf73\xa4\x8e\xc3t\x9fw\x90\x7f\x0e\xd0\xd6\xfe\xda\x00\xe3\xbc\x9c\xc2D\x16PI\x8a\xee2\xd1?\x12\xe0\xca\x0c\x99"
        b"?T\xb5\x1cI\xb5\xadW7\xd0pL\xf6\xafj\xc4\xa97\xc7\x87\x8f72F%\x02\x97V-EB\x1b\xd3\n\xd0\xf6-\xfa\xfdZ\xc7\xa3\x13\xbb\xb4\x9b\x08\xac;\x07g'\xab1\x96\x8e\x13\x17\xae=\xecE\xf5\xf2"
        b'\x11\x17\xf0Q\xfa+1V\x9a^!\x89\x94\x16/\xef \x12\xc6\x96\xa5\x9c\x83\xa1\xdd\x03rce\xe1\xa7\xa3n\x1d\xfc\xea\xaam\x1f\xc7\xc3D\xb7\xc6\xb1V\x91&wM(\xb1vCP\xee\xd7\xb6\xbeG7\xa7\xeb('
        b"\x1c\x97\x96|12\xc2.L\x99\x08u\x9e\xd5\xc7\xfb\xc3\xb0\x05\x0ce\x06\xdbL\x92;#\xf2\x7f\x960\xd7\x88\xce[\xca\x06\x0cM\xad_\xbf\x1e'\xf5\xb7U\xc7\xa5\xa1D\xfa\x18\x84\x05\xd6\x87*\xa8\\H\x86j\x14"
        b'\xd7c\xeb\xb6"\xe2\x9d\x90\xf9\xeb\xc3\xe4&\xe6\x9a3\x86)7\x950\n\xc8X\x93\xfc]d\xee\xbf\xe5\xad\xacRq*\x08\xec\x93\xb3\x04\x7f\xbe $@\xc9\x1d\x8c\xa5z\xf2\xbd\xa1Q\xbf\x8f\x93\xd8\x12\xd7Q\x14\xd7'
        b'^\x93C\x9d\xac|g\xef\x91\t\xfa\xdd\xfe}\xa5\x1a\xb0\xef\xf9\x9f=O}\xfd\x15\xafHtW\xb0\x81,\xee\x96\xec\x08\xa3\x1d\xed\x89bZY\xc5R\x1b\x12\xb9,\xa2\xd5>?2\x83\xa3f\x9d\x14j<\xd3Ap'
        b"]\xd6\x90\xb6\x8c1\xf6{\xbd\x00\x03F+2\xca'7\xb0\x80\x9a:\xb7\xdcJg\xca{\xc5\xf2%7?#d\xe27|`\xb5~n\x00\xdf\x15\x8e+lq'\x14J\xe1E,5\xa4\xf3\xc1\xc7\xd9}\r\xb7y"
        b'(\x95I1\xfc\xa1 \x15\xd4\x1eB$>\x8f\x9e(*\xa11\x8e\xf4D}\xce\x87w\xc1\xd8Z\x8f\xe7m\x9c\xecP\x96\x8f\x9d\x8b\xac.\x7fP\xe3Or\x8ca\x11\x17\xecG\xaar\x9a\x0f\xaa7\xc0\xc7\xce\x15\x01\xec'
        b'\x0f9\xff \xa1S\xa3\xb1G\xdf$Y\x083\x91 :\x0c\xcb\xfa\xf4\xd2\xad\n\xfd\x98\x0f\x98L\xc5\x1b9\xb9x#y\x8e_\xe4\x0e\xc9\x98ZV\x07\xc4\xd1\x17\xde@-6\xfa\x8b\xb6S\xcbQ9Ze2`\xae'
        b'bIz5\x15\xedz\xf2!\x94\xdc\x8f\xde\xb2\xc8\xbb\xb3\x89G\xb9hS\x9e:\xd8\x88^v\xc8\x7fE\x0c`\xb0,\x15D"\xe2G\xa7\xed1l\x85\xc0\x02m;\xdd\x96\x08ap\xda\x11J\x9e\x1ax\x07\xdef6'
        b'\xc0\x8dSS.T\xb1A[B\x18\x95\xcdq\xcb\xd8~\xaa\x93\xde\xa5\xb0NK\x9aI\xc9\xef\x9a\x0b\x83\xb3LJ \x97\x98>\r\x94\x19d\xd2\xeb\x02\xf4\x92\x94>\xf5\xc8\xf2+VY\x80\xbd\x80\xe5i\x1a\xe8\xe7\xab'
        b"nc|\xa57$\x04\xf3\xd0n\xb2\xc9E\xae\xd3w\xabX\xc0C\xea\xee\xcd\xbd'\xf3\x0b\xcbU\x1b\xf2\xaa\xdf\xef\x17\xcd\xf2&\xe8D\xf5f\x19\xf18\xa2\xb1P{<I\x1d<\xa4-R}\x04\xfb\xb4\xdf'],"
        b'\xda\xe1U$|\x8d\x7f-\xcc\te\xf0\x04\x00sbC\x1a\n\xb3\x11`\xc1U\xb9\xe1G\x8a\\o\xf3\xa1SH\xea\x03\xd2\x1a\xf3?\xe8U?\xc0\xd8\xca\xe2\xff\x8b\xdb\x10\xdc\x89\xb6\\\x17\xd6\xa0b\xc8\xa52/\x87'
        b"\x97\xe0\xednMg\x98.,\xb9\xaa\xfe8\x8a$`\x7f\xf7\x8e\xbeA\xa3\xe5\x12\x8fb|\xcdO\x84\xf5\xe7D\x7f\x08\xa0n\x93\xee\xea\x9f8\xbc\xc0\xc4u'\x03\x0c_Q-%\x05\n\xc0I\xc3I(\xfc\x84\xa0\x08"
        b'\xda_S,\x8d\xf7\x04[\xf0\xc4\xc6\x1e\x15v\x07\xe0\xb6\xac"*\x0b\xe5\x93\x14\xd3\x8bU\x1f\x80cs-l4\x9e\x89\x83\x16\x8c\xeby\x1a\xd4Q\xffM\x01\xb9\xf0y\x86\xac;\xf9\xdc\xa6\xfa8\x0eu\xa8\xd6\x05\xc5'
        b"-w\x93\x04\xb6\x17B\xfc\x8c\xefJ\xbf\x01(4^\xed\x16\xf6x\xff\x8c)<^i\x80\rb%\x94h\xcf5\x81\xbc\xe6\xe2;|}\x14Dk\xc2\xf9\x1e?v\xb7'4\xa1 A+\x0f*V+>#\xfcQ"
        b'\x19\x14\xcf{\xa6p\xc1&\xc4\xbcL\xa0\x88=\xd5\xe9\xa5\xe8U\xee\x9a\xe5\xd3\x1b>\x8ayn\xcb1c\xfe\xf6\xab\xb7r\xfb\xc1\x9a\xc6(q\x14\xe1\x054\xf0\x98\xe3\xa9\xb8\\\x92.9\xf5\xf5?\xa1\xd2-\xa8\xe8\xdf'
        b'\x18\xd1\xe4\x82\xbaz"\xdf\n\xc3\x9b\xcbp\x00\xff\x1dm`.l^WS\xcbd\x89\x00\xb7\xe3\x9b\xa1]\xf0\xea\xc9\xbe5E\x8a\xf3\xc9\xbe\x9e!JA>t_\xc4+\xe9\xf7"Rn\x88-\x8c\xc7\xf3Q\x03\xd6'
        b'2\xc6d\x93\xf1&\x8d\xd4\x80x\x9f;\xc7\xd8_z^p\xec|\xc76\xbaD2\xfc{m\xd6\x07\x0f\xfa\xec~\xdd\x80Mm\x1fj\x15n3\x84\xfb\xa1\xde\xe8\xef\x95\xfbHT{\x0f\x05\xaf\xd5H;\xdbn\xea1'
        b'o\x8b\xc1\x9a\x11\xbe\x1c\xb77\x12\x7f\xe5Pi0\x0f\xe9\xaf\x8f\x98U\x87Bg<OARIj\xc8\xbeQ\xc9k4j\x8a\x0e\x86\x03Jy\x01\x9ao~\xacd\x94\x01D\x7f\x12;G\xaeK\xbf\xdc\xcdL\x7f\xda'
        b'\x03\xde\xc1Bw\x80\xcf\xde>x5\x14\xe4i\x8b\x9bX\xe0\x8buk\x0f\x05y-\x01%Ws\xb5AI2\xebE\x00\xafG\xa8\\\x08/m\x881\xaa\xa2Z\xd5\x81a#\xad\x10I\xec*t!\x14\xe3\xa9\xd3\xc4'
        b';h\xa35\xe0.8@A\xb1\x95\xeb"\xe7\xb3N\x0ew\xe1\x00\xc3\x94uv\x17ns\xbd\xd1L\xecp\xb0\xba\x060\rL\xfek\t\xe4\xf33R\xbb\xc3eo\xc7\xd4\xd5\xfb\xa4(\xd7\xec\xe4\x92\xe5\\!\x8e\x19'
        b'P"\x15L\xe7\x0bf\x03KOh\xac\xda\xa7\xf8\xd1\xce\x10\x1e\xf1\x88\x93\\T\xb1O\xb2xEb6\x92P\r4\r\xb0\x1a\x8d\xd0fP\x19\x05\x94\xda\x84e\xd7|\x93\x08\x18\x84\xec\xb1q\x9d\x98\xfbR\xef\xedj'
        b'd\xc1\x05\x05\xa1\xfe\xaaL\xd3nF\xcc\xf2S\xf3.\xcb%p\xba\xb4r\xa9\xdfj\xa3\xe5\x9b\xa0F\x96Y\xf6\xf4\x96\x990\x8f\x86\xebWHdA\x89)T\xb1\x84\xda\x81\xba\xfd\xe0\xd2u\xb6\xf8\x02\xa6\x1c\xfc\xed\x1c'
        b'\xdc\xe0\xe5\x8cDgX\x0f\xc2*^\x11\xe5\xcb\x02.g\xfb\xd0\xca\x15qjW\x97x\xa4\x9b\xaa\x00\x1e\xbd\xa4t\xc1\xe7\xc2U\xa6\xb9\x8dw\ry\xb4:\x85\xa0\xd1J\x0e}\xdd\x0b\x9e\x13\xf4/H\xe94\xb7m\xac'
        b'\xfb\xd4[h\xfc\xe4\xfd\x08\xc3\xa3\x0b\xdf:\x12\x17\xed\xc7\x19\xcc\xc1\x86\x0eA\n\xd8\x9a\xbaZ\x97e\xfbR\x95)\xa4x\x02n6\x12\xb3\xfc\x9a\xa2\xb9\xe6t\\\xed\x11\x8f\x11\r\xf8\t\xd7\xbc\x87\x15"{\xde\xa1\x1d'
        b'\xec\x99\xa0Tm\xc3\xd9\xe1\xe5\x0c\x051|H\x1d\x1c\x9d\n\x88\x87\xf4OW\xc4i\xbe$\x7f]$\x84{\x02E\x8a\xc7\xa3\xd26\x92\xcd\xee\x91\xe5u\xa7#\x11Y\x0c\xae:\xcfv\xb6\xc5\x93\x8e\x81\xc2\xf1\xa6\xd0\x9e'
        b'\xe7m\x99\xe9\xe3\xa1\x8e\xea\r\xa5\x8e\xad\xe6;\x15x\xc0\xe9\xb9\x1a\xf8-dwO\x9d\x8f1ck\xa1R\x90\xb2\x95\xb9\x0b#;v.R\x9a$^C0\'y"VDzf\x1e\xa5\x0b\x85\xa5 \x05\xd4\x01\xc4'
        b'EP*\xa6~\xdf\xf9\x14kY\x96F\xdf\xa4\x80t\xe92h\x9ew\xe2;\xf0~\xf85\xbd*\xa6D\x0c\xe8\x95G\xb2,\xd9b`\xb6\xca\xd12P\xfe6o\xb2\xa6\xa8\xf7$I \x16n\x17J\x13\xbf_\x02\xac'
        b'\xc7\xbbQ\x95xJ\xfe\x98\x82\x84[\x85|\xf1\x01\x02*\xc8\xfd\xb1\x97\x81<\x06\xfe\x94f{\n\xfd7\xce\xe0\x87\x81\x99\xfe\xf3\xc0{\xa2\xf6\x9c|O\x89\xb7](\x7f\xc4\x9a\x8d \xa1O\xd6G\xd9\x19\xf0\xb5\x1dt'
        b"(\xd8\xac\x91\xca\x9c\x0e\xee\xd5~\xf9X\xa8T\x93(\xbfE\xca\x84z\xc8\x18\xe8\xbei*\xca\x96\xf2\x0f\xea\xc3\x9e9+q\xec\xad\xebR\x18\x9e\xa4\xfb\xdd\x1c'\xc4\n\x9e\x07O\x94\xf0\x1b\x15\x93\xe6\xc8\xec\xe5\x99s"
        b"\xf6@8dY\xaf\x9fW\xbe\x00\x07\xb5\xcb\x8e/\x16\x8c\x9a\x8cF j\xcb\x88k6\x93\xbcy\xe6\xa5\xf3\xe2&H\xcc\xfd\x0f\xaf!\xe7:'\xf1\xeb\x9a\xe4\xab;\xc5\xc7\xbe0\x1c{%\xb5\x7f-\x9c\xf3s\xd6\x9d"
        b'\xe5p\x88\xe0\x97.\xa7\xc1$\x87\xb1\x11\x7fycv\x8f\x80y\x08\xc6F\xe8\xc7A\x17[\xe9S\xa7\xfd\xbcD\xb4)C\x90\xf7\x1f\x7f\xa7V\xca\x96\x19\xddYM$\xea7~\xa8w\x90X\xddw\xfbs\r\x07)\xa2'
        b'\xf6\xe5\xda\x91\xe6@\x97\t_\x93A\x8e\xce\x9a\xc6\xb0\n\x89\x90hN\xcd\xd6%\x8aGBl\xdc\xef\xc78\xff\xd2\xd5\x90\xe7\x8d1\x83NRE6\xdc\xe9\xe5P\xc5\xe4\xe7w}\xda\xb7n\xf6\x1f\xc3\x18\xe6Y\xe8I'
        b'\\\xf7\x83\xb2i\xbb\xf9\x04\xe4\x96\xea FF\x7f\xddl\x8e\x07\x95=\xf1\xa7\xb8J\xa7j\x0f\x0b2\xc1>\x80\n\x99\xdfBE\xee\xb3\xd3\xb1V\xfb\xc4\x914\x9chOz{\xb2\xebq,\x02\xf3\xfd\xe1=&\xf0Y'
        b'\xf8\xd6\xe72\xc9\x9a\xdd]\xf8P\xc4Bb\x16\rw\xb7_`\xee\xd7s}\xb8\xb9\xe4\x861d\x80#i\xf9\xb6\x01"P^\xfaX\x8c\xc8Q\x0f\xde\x8b\xec\xde;\xe6\xadq\xd6\xb2\x84\x0e\xa6Vh\xbc+O\xd8\x85'
        b"B\xd9`z$\x88sY\x19~\x8d@\xad\xe3\xd2\xe2\x8bM\xbb\x81w\x07\xdf~\xdbE?\t\xfd\xfalKA*\x06\r|\xeb\xf0X\xa5\xe5Qdw\xd6<\x9c4\x87\x92}b|\x0e?\x879\x9c9\xe3,\x85'"
        b'\x83\x10\xf8\xf5\x7fi\xc7y\x04~\xd7\xd1\xb5\x82\x89:\x8b\xec=\x99n\x97\x94\xc7\xa9c\xcf\xec&\xf1\x1e\xbb@$z\x04\xc9i\xc0\x0b\r3B\xed\xe7\xbd\x97i\xd0_\x886x\xfc\x85\xd2\xbdnA\x86\x12\xb7\xce8'
        b'T\xe3\xf9\xd3\x07o\xfc7$v\xb56e\xdb\xcfe\xaa\xd1\xfb\x17\xc3\'t\x13\xcf\xa7ums\x14\x16\x8dl\xc1\xc2)K|w\x9cj\xcf\xf1\xe2\xb8*\xef\xa7\xb7\xcbi\x1b\xe0\x07\x12\xcd\xa8\x97"\x99\xaf~\xda\xcb'
        b'\x13L\x05[\x90$_Tg\x0b0\x19WN\xca.\x92\x8b\xec\xdevA\xbc\xb1\xb1a\x84\xaa$\x11r5\xd4\xb6U\xe5\xc3\x11\xde\x17\xa0\\^\x90\xec.]z/Q\x85\xab\x8c\xac\xaeK\x7f\xf6\xb2\xc8\x8d\x01\x11\xa4'
        b'\xa4\xe95\xb2\xe8W\x9b\xcc$\x1b\xc9\xa9?\x14G\xd86V\x1fH;tKp\x9a|h\xa4\x81\x18\x8d\x95\x8d<\x83(\x9bq\x96\x98\x08\xe1\xe7\xad\x85k**\x93\x10\xa7\xe2\x98\xf9\x1b\x06i\x97\xa8\x8f\xfb+8\xbf'
        b's\xf6\xa1\xc8\x85\r6\xa6\x8b&\x16)u\xf2\x8fv\x15\xee\xab\x88\x14\x14\xf8\xaa\xdc\x0bv\xe6\xf7\x16\xf0\xe7\xe7\xf08\xf0\x1b\xb1S\x97\xee\xc9r\xbf\x01z\xb01o\xf7\x8d\xcfwgMq\xc4\x93vv\x88\x0b\xeeg'
        b"4\xf3E,~z\xd6\x8f\xa2[^\xbf\x83\x1c\xbe\xf3\x95f>#\xb3\xe4$\xaf\xe7\x91\x1aBV\xbeu\x13\x04\x06\x7f\xb8\x92]\x97&.\x0f\xf2k\x88H\xf8\x00\x18'\xb1\x96E6,\xfb\x1e\xa0\xa4\x03\x80\x81\xa0\\"
        b"8\x11\xca\x0f3\xa6\xe4\x0c\\x\xb8\xa6\xcd$en\x15\x18\xdf\xc1\xb6</\xbc\xa9\xf4\xf9z\x86,\xa3\x89\xb5*e\xe6C\xa4(_\xf8\xde\xc1\xb5\xb17\x1fK\xd0\xb3\xd6\x88\xb8\x16\x14m.\x81T\xabU\xb4'\x9e"
        b'\xae&\x1fP\xd3\x9b\x89/\xd4\\\x02\x9d\xc3\xf6\x99\xdd\xb7,\x95[\xd4\xf9\xdb9\xc2\x8f\xf5U\xa1Rw\xa2\xa2C\x7f\x98W<b\xee\xe4\x8c\x8fqb\x8e\xf9S^\x87z\x88\x92d\xf02Ok\x1e\xfe\xcdD`\x12'
        b'\xc6\xe8\xad#_U\xfa\x05\x85x\xae\xc9xb\xdb\xc5\\\xda\xed+\xad\xcb$\xd4W8\xc7\xda\xd7\xd6\x86PF\xd1\x91)\xcdS\xe4U\xb0\x0f\xa9\xe0\xdc/\xb8\xad\xc4\x11\xdfG\xee\xe0B\xe5\xe0\xfc"L`\xc1\xa3{'
        b'f0\xf0\xb7\xcf\x10\xb6\xa4\n\xafcQ]\xb8\x98AT\x84\xca\x90\xe9w\xf2hD\x88\xa1\xfc\xc2I\xc7\xce\xe3u\xef\xa8\xc8\x9b\xb7\xb5Q\r\xaf\x11a *\x08\x10P\x89.y\x8b\xe4\xcb\xb3\xb8\x9c\xc8B\xa38\x12'
        b'AGv\xa3\xd0\xbf\x10\xcb\x9b\xb0\xc9Q\x11\xb2\x0b\x01\xef\xbd\xee\xf7E\x84\x90M8\xe6\xa5\xa8N\x1cE\xc2\xd4"\xbd\xb1N\xf9\xe7D\xc3\xab^\x8e/8}\'\xb0\x86 \xbec\xd7\xdbaQ-.\'\x12\xea\xc4\xb7'
        b'^\xf0\x1f+\xf2\x9b\x1f^\xdd\x98\xb8\xbfD\xa4\x90\x01\x88\x99\xa52\xe0\xab\xd3LiA\x8d7\x13B\x08[4\xe3v\xee\xe5\xe3\xdd)\x02\xc8\x90\xfaJ\x8c\x13]<\x8bL\x94\xb4\xd5\xc3\x86(#\xc0\xad\nt\x0bA'
        b'\xbd>\x7f\x00"\x89\x87PR\xed5\xc0\x94+\xa0\x86\xa8:\xad-g\xc4\x82;\xc6{i\xc2\x8aK$\x81\xe3\x91\xd9\xcb\x06\x9e\r\xe8\x05\\s \xbf\xfeG\xebu\t*\xdc]\xbc\xad\xbaG\xad\xa7cX\xa5J\xc4'
        b'\x8dBL\xf9\xa51\xff\x0eP\x95\xb6r\xb7A\x92\xf0\xadx^\xbe,\xd9uCn\xc4\xa1\nQ\xb9\x9d\x89\xa7\xa4]\xf6\x07yL\xd8\x19\x06P\xc9\x894e\x84\x07\x1d\xbd\xee\x8f\x80\xa5\xa3\xd6+\xe8\x89u\xff\xdaD'
        b'*s\xe8\x9e\x94\x9do\x08}U\xee\x13\xbd\xb94{\x91\x13\t\\3Eo\tc\xc6\xb5ow2\x0cnZA\x8b\xcf\x1e\xf4\xb4 \xd3\x91\x7f\xbbnc\x90\x93\xdb\xf4aNq\x82\xbb\x87S(\x08\xf9\x02\xb6G\x85'
        b'1K]\xb9\xac7p\xa4\xa0wn\xbc)\xc2\xca\x16\x94\x91<p\xfd=\tJ\x7f\x96\xe7\x8c\r\x05\xd2z\x86Sx\x18\xda&x\x99\xee,\xdcN\xe0E\xc0K.\xde\xa2{&fT\xf8{{\x1b\x8c\xdd\x0f\xd6\xa9'
        b"\xbb\xccbzZ\x8c\xc6M\x15\xf1\x9c\xec'\x9b,\x12\xe8\xe1\x1a$QK\xe0\tw\xe8\x9eC\xbboqLYR\xffBQ\xd0\x9aUS\xd5\xe2\x11\x02\\\t\xaa\xb4\xc5\xcd\x1a\x16\xd37\xe1\xfb\xc8\xb1\x86\x1dE\xc4q"
        b'w\x96\xbd\x91.\x8f\xa8\xa7\xde\x14\xbeQ\x8e\xa4*\xf2\xeb3\xdc\xa6X\xd6\xa9\x97K\xe9F%<\xaet\xacy\x13Q#~\x06\x8e\x93o\x00\x95\xd7B\xe0\xbf\x86\x97\x8dSj!\x92\xf9a\x1e\x18\xe7\x9c}x\xf09'
        b'\xad\xea\x13y\xa8\x17\xa5\x87\xb1+7\x1aeS@TJx\x96\x19Sy\xc6\x91\xa7y\xa4\xd5\xa9\x17\rf\xc5j\x19\xd0\x8b\xaa\x9f\xcb\t\xe3\r\xa1\xf5\xd2\x8e\xf8\xe8sU\xc9:!C\xfd\x17\x8a\xfc>9@\x02\x1e'
        b"\x8f\xa8\xb3\xc4\xd8\xab\x18\xa4\xec,?\x13]\x93\xd4'\x15f\xcf\xf2uz\x86L\xf3\xdf\xf3mt\xad@\xfd\xc8+\x9b\x15\xbc\xc1\xf5=,\xfdC)\x86\xedpT\x06\x9a\xb4C\xfd\xe6\xf7\t\x13\xc7P\xa9.\xca\xc8\x8b"
        b'\xc6\x87\x9f\xca%\xae\x01\x1e\xd0\xfb.x\xed\xc3\x0b\xcd%\xcfN\xe6\x97\xffz\x7feWn\x00\x9e"\x1ek\xb0\xbe3\xc5So\x90\xf1\xb6z\xcc0\xf7\x17\xb4\xdf\xec\x85\x08\xd1\x92p\xd3Q\xf5\xad\xc5d\x85\xb3\xfc\x1c'
        b'\x82.\xeeP\n\x9e5\xbe\xec\x8d\x9c7g4%\xfa\xf0\x13kQ&KR\xf8s\x0c\x1ak\xf0\xb6r\x96\xc9\xf5\xf6\ng\xc6\xe6\x07\xb8\xa0\xcc\x0c(K\xcau\xa2\xafIX\x1e\x1a\x91v=R\x02\xf9\x93\x12\x06}'
        b'{\x83\xb8]b*"\xf6D\xbf\xa4Q5z )\xae\xa6\xfbP\x83I\x8b\xec\x8a\x1bR\x10\xfc\xec\xd6\xae\r\xdc\x0c\x94\xcd\xf1\xcb\x00\x05=E.J_\x10l\x15o\xb9J\x13&\x9c\xb5\xba\x85\x1bz\x93z\x89z'
        b'\xe2a\x10\x8ez\x1e\xe7\xc6F\x1e\x02\x9aW\x92\x15\xd4\x87\x995\xa1.`\x8ep\xed|R\xd7\xb2\xf7\xde\x93\x99\x1f\x8c\x87q\x7f\xb8\xfd\xa5\xf8UA|\xd4w\x86\xbd\x88p\xb5\x1d\x0f\xa3.`v\xb5\x9d\xdb:\xbb\xa9'
        b'Vl\td\x0c\xd6\xcaD\x06R\x9b+\xda\xf7\xcd\x8f\xd0E\xf4[0\xf5\xcc\x8f\xf9d}\xb9\xf1q\x1aM\xf8\x9e"B|\xdc\xf6\xba)\x12{\x87\x12\xd6\xe40\x1e\x9d\xb5O\xc7\xb6\xde\xf1\xee]\x98\xa8\xafw\xc5W'
        b'Ym\x13\x11J\xa6\xb7\x05\x0b\xf0\xae\x92`S\x0e\x81)|\x81\xc1lR\xf5\x92\x1c\xe355\xf3\xb2c\x0eK\xfc:\xecf\x1aI\xcbl\xeesA\x1b^Hz\xda\x841\x95\xa0\xb1\xe80\xad;\xc4\x04\x86{&\xfe'
        b'\x85\xccs\xd3\x10\x87d\xa4aHq\x14\xb6\r\x89{\xe4\xe5\x1d\x18\xd2\x01\x9b\x9d\xde\x86;\x83r\x91_\xb0$\xa1\x99Z\xdb\x18\x13U\xf1\xe9+\xe6\x14\x05\x9b`\x96\xcdH\x0f\x8a\xc7\xdb\xb4(\x1c$\xeaT\xc0\x83\xf7'
        b'ry{\xe6_d\x1b|\n\xf2\xf1N\x89\xda\xe5\x1f\x90g(/v\xb1[W\xb9C\x13\x8e\xb5\xff\x8fV\xf5\x0e\x8a\xb9\x94U\xe1]TYk\xec\x043\xb0\x93\xf6\xe9W\x93\xc788\xd6\xf6\x0e\x02,\xd2\xda\x94}'
        b"\x82\xe3\x1b\n\xac\\$\xb9w\xa5}')\x9c\xb9\xeb|\x15q\xcf#1\xe3K>B\xf8\x91\x8f\xe5\xa3\x9a\x95\x00\xee\xf0Jz\xdcuV7\x99\xbfg\xcd\xc8\xd4aD+F\x0f\xd5\x8d\xc4>aTa\x1d\x91\xdf-"
        b'_\x1a}B\r\xb2\xc8n\xcc^i\x80s\x8f\xa5*\xeb\xcc\x03\x1b,\x84\x91\xc8\xe5\x08\xa1\t\x9a\x0f\xbea\x12%\xadh\xbe\x86\xad\x03A\x8b\xc4\tS\xfe\x05\xff\xb9\xcc7O\xff\x16\xa9\xbf\x9d\xd9\xb6\xfa\xb2\x10\x91\xf5'
        b'\xafs\xf3\x18#\xaa\xd8(\x9b\xa0Q\xb1&\x9cP\xc6\xe2\xc6yo34\xfa\xc5\xd3\xf6\xfeV\xd6\xb7\x95\xc0\x81\xd1\xe4\xd9@zl\xe4[\xe4\xa7\xb0}\x96\xf8\xbc\x95u\xfeg\x9a\x11T\xd5[\xd3eQ\xae\x9c\xd6\xf0'
        b'\x8a\xf8\xb0\xa6\x06\xc7\xe2\xbc\xbe\x01\xba\x17D\x82X5\xde<W\x1e>\x07\xef\x18Y\xa4\tJ\x91No<\x11\x16\x82Q\x00\xc3.26\xb9Ul?\x02\xe8\x9b\x12\xc9L\xad\x1b\n\xb5\x19\xb49\xa4\xe8\xf2\xb4\xdc\xc1'
        b'\x86}\xc6\x8f.\xa9\x1a\xb0\xd7\xb7\x83=f\x01\xf4\x9cA\x88\xc3\xb8\x860\xf7\x11\xe6kN\xe7D\xb9\x1e\xd8Y\x0c6H\\\xbeQb\xad\x8cRK\xbb\xd7A\x13\x13\xeb\xd5\rG\x02F\xf6\x82\xf5\xe5\xce\xfew\xde\x92'
        b'iiQ\x05\xe4\xe4\xe9\rm,^\xb6\xcb4\xa6S\xe1\x8bip\xce\xb0\r\x8ec4\x13b_y\xfc\x98tp\xbd\xc6\xd4*\xdf\xdfJ\xf7\x1e\x91\xab\x97\xf0\xef\xb2\xffJ\xe8\xf9\xbe3]F\xd9\xbaQ\xfd\x96|a'
        b"'lJ\x04\x07\x1b3\x8a\x85\x9d\x82\t\xc8;`9\x82\xc1A\x18b\x07_\xde\xa3\xb4\xb9\xea7w\xf1\xf4|\xc6\xc8\xd4\xbe\xcd\xf1\xde\x10\xfa~\x80\xa3kd<\r\x8fCk\x14\xd5\xf5i{Q\xa3\xbfT\xb4be"
        b'[|\xf4\xe7\xc1\x92\x00q6Y\xe6\xa5\x8a\x82\xa7\xa6~\x17nC\x0bg&\x8aI\x9bS1t\xea\xa8\xbbq\xa8\xaa3\x00\xd8\\v\x14\xdc\x19vG\xbfW\xab5<{=4Z\xd6SZ\x9b\n\x06,\xd7\xfc\x0f'
        b'Y\x83\x94p\x9c\xdeB\xc6\x8a\xe5\xa8\x11\xa8\x13\x86\x95|-\xda\x1b\xa5\x8c\x82\xad"i\x05\x0fA\xd9\xa7)\x00t\x86\x9fM\xcb\x13\x1b\xc2;\x96\rR\xc5\x8d-\xc8\r\xf4\xdd\xcf\xdc\xec&\x9f\xe7.\xfd\xa1\x07\xc3\x16'
        b'\xa7!CG\x01\x98\xc2\x1d \xa6\xd9\xde\xb2\xdfx&$^\xd4\xe6\xc8`\x16=/\x9e\x00G\xaf\xe1f\\\x9b\xe2qt\x8e\x95\xec#\xf6\x8e\x82\x96\xd6\x1e\xcdR\x03\x8f\xc9B\xeb\xb1\x8b$\x1c\x0bLl\xea\x08\x9f\x96'
        b'f\xacm$:2\xfd-\xa5\xb8\xbbY\xca\xd5;)\xbd\xe2l>\xa3\xbdt\xa2\x90\xd7\xd1pR0p\x17|\x05_\xab\x1fC\x1fa\x98\xb9\xff\xf4\xbdI\xbc\xb0\xab\xd7\xed\xa3\x8cz\xdb\xd9A<>\x9e\x9c\xdf\xe8\x14'
        b'\x1a+\x87\x8f\\\xbeo\x11\xba\xea\n\xa9"\xbdA\x8f\xff\xb6@\xbdPR\xb5\xa8Z(\xabE\xbb\xfd\x89\xa9\xaa-\xbec\x04BZ\xa3\xea4\x00\x1f\xda[A\xbc\xf8I\x06\xb2t\x94\x16\xf5\xdb\xa2\'\xf0\xa7D\xe6k'
        b'\xe0,L\xbb\x1f\xea\xa4\xf1\x98V\xea\xda)z>\xfd\xec\x7f\x95\x10\xbb#uZ\x98\xe4{\xad\xd8\r\x91\x8ewc$Z\xa5\xa3\x0b\x02\xcb\x00!\xd1u\xed_\xbe\x9c\x81\x8b\x0b\x90\xf8Z\x1f\xf7\x0cZz\xedn\x94!'
        b'\xafW6P\xaek2\x9d\xe47\xa9H\xc9\xb1shO\xfb{W\xb3\xaa\xdb\x07\x1et\x9d\x92\x81\xf8\x91\x00J\xf3s\xb6%oo\xcd|D\xc3\xaf\x84@\x04\x8d\xfc%J\x1f#4\xbd\x11\xde\x1e\xefE\xf5\xadyE'
        b'\x96\xfb\x9e0\x01pz\xd0\xf6\x9f\x08?\x0e\x11\xfd\xf8k\xdc\x1bS\x13u_\xf7*\xcf\xc4\x98\xb0\x92\xf75\xaex>\x0f\x96\xa9h\xb4\x95,\xf6<\xb8\xffNe\xd4\xce\xc3.\x81\x857K\xf5sB\xbeK3\xc4]'
        b'P\xbbz\x7f\xdd\x8f\x80\x06\x1e\xf2PF\xb74\x8d\xad\xb7\xa1\x01\xb6\xd2\xb4\x00\x02\x8e!\x97>XTV\xd2\x92\xeaa\x13\x05\x81-\x06@zh\xe3~u~\xc7|\x94\x8b\xf0n/\x1a\xb9\xebXZV\x18\xd2u\x90'
        b'7V\xdcr/\xa0;\x0b\\\xca\x17\xd91_\xaa\xb7\n\xa2\x82\x15\xe5\xd9\\j\xa2\xa7z \x13\x15i\x86Spz-\x8b1N&\xcb\x15\xbe]\x07hb\xd0P\xaa\xe7\x85}\x93Q\xed\xadQT\xd2\xc2c\xf8\xa6'
        b'\n\xce\xac\x16\xd4\xb0\xe9\xf9\xa1\xb1\xef\x14a.\xcd\x81\x8d\x1c\xad\xca\x11\xd3\x9b\xf5\x02\xc1\x87Q(\xb7\xf4\xf9E\xbb\xd2-\x11\x89\xa4\xe7"G\x13\xa3\x85\xa8\xf7\xe0\xa0\xb3\xf1\xf6\xe7\xeax\x81:\xd8\xc2\xe5a1\x95\x1d'
        b'e\xb8@u\xe2\x87Kn\xbe\x18\xf2\xa2\xa9}\x82\x84I\x144F\xae\xfa\xec\x9d\\\xac\x1b1\xb3\xb2[\x99r\x89\xcd\xb3\xa7\x8d\x92+\xd28\xf7B[\x0e\xd9\x9f\xa9.\xdf?\xf8O\xb5B4u\xb8\xf9\x00\x12Y\x80'
        b'\xe2u2H\x03\xc4Y\xef-\xd7\x98B\x03`\xee.9\x02\xfc\x16\x0e6T\xb6\x9c\xb0\x9a\x16\xc4\xf6q\xd74\xc3Fu\xcd\x18\xe4!D\x059P\xb9\x1eG&\x87E\xbcI\xdc\x03\xdcr\xed\xbb5u\x18rc\xec'
        b'Z\xce\xcd^\x80\xcb#\xd9\x93B\xfe o\xe5\xeflg \xae\x12\x10\xa1\x860\x03\xb5\x7f\x1c*\x96\xc1\x12"\xfe\x98\x86K\t\xa95\x07\xceI\xe8\xfb\x83\xee\xbe\x04r\xe7\xbdVzp8\x8b* \x84\x95E\x8d\xbb'
        b"j\xe2\x15.2\x98\xa7\x1fO\xcb\xb1\xcb\x91\xf2*\xdd\x86\xeb\x9e\xee\xd2':\x01\x87\xd69+@\x04\xa1\x91\xdf\xeb\xbd\x89\xfb\x0b\x18\x84\x07\x8bY\xe5\x9e:\xf91L&\x8c\xdb\x11\x8d\x15\xd9(W\xc61\xfdyH\x0b"
        b'\x93Y\x01\xea\x14\x89E\\\x08\xac\x1a\x93b\x9f\xfe\xd0\nw\xe3\x8cv\x0e\xef\xf5\x98\xbe\xf5&\xd1\x17\x0e\xdbCA\xc0\xach\xfc>\xb7p\x02\xf0x\xca\xc1\xb0E\xcd\x8bP\x86\xbc\x1b<\xc4\xa8\x03\x83\x91j\x8f\x07\xde'
        b'E.\xbe\x02\xf5\xabAG:S\x88h@v{DS\xb7\xe6m\xdc\xee\x0e\xed\xf2\xb8\x9c~\xc9\x9a\xcc\xca\xfc\xef\xfd\xd4\xfa9X\x8e\x1e\xc8}\xdf\xd2\xd2\xe0\xeb\x97\x8a\xe9\xe4\x00A\xe0\xa5\x0b3\xcdO\x81\xfd\xce\x99'
        b'\x02[\xf3\xc6\xe4\xab7\x06z\xc5a\xf4\xa5\xf7J\xd7\xf7\xad\xf6\x8b\x9f3\x0e\xfa\xdd9\x9e\xa0\xd9]\r\x10\x00\xa1\x83K(\x1d\x88NM:\x83:\x0c\x81\xbaF>\x17\x18\x1e\x9f\xbd\x98\xcbn\xe9\x01\x00\x00\x00N)'
        b'\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<f'
        b'rozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
