
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsd.\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00$.\x00\x00\x00\x00\x00\x00\x9f:\xb3\x17\xc5\xee\xd2|\xa2\x80<\x9a\xa4\xa6J\x98\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=e\\X\x90\xa0\x12\xd8\xbb\xf9\x05*\xe2-ou\xb4-\xc8\xc5\xd2\xb9~\x17u\xb94N(\x0cfc(jdr.\x04\xb4\x01n\xa7)`\xb04\xfb\x87'
        b'\x7f\x9c-X|K;\x00\x8e\xb5\xd7E\xc0QF6\xad\x01\xad\xee\xbf\xb5\x06y\xce\x19\x0b\xf5H+\x079q]\xbaE\xee\xfe\xd0ii\x96\xc8\xba\x07\xd5\xae\xa9\xb3\x12&^\xcea4\xa3\xf42X\xe7\xbcw@\xcf'
        b'7\xddb\x02\xc71\x8d\xafOh\xba\x0f\xa4\x1e\x8a\xe1\x93\xaa\x7f\xb0)\xb1\x06{Nh\x8d\x83$v\xfb\xecv\xa1\xe3zN)\xe8\xf2\x0c\xaa\xe7Vl\x8d\x93\x1e\x81\xff\x9e^OA\x81\x8d\xcaB\xc8L\x9d\xfeIQ'
        b'\xd9^\xaf\xeb\x1e9\x85Z==\xed\x9d\xa0eD\x0e\x80=\xa2\x01IW4\x9f\x089"\x89\x9a\xe62\xfc\xca\xfd\xad\xfb5_\x808\xd6\x07j\x8d@\xa9\x0cr\xc5\xf8\xf8\xab\xa4m\x8e\xb2\xc0\xa1Jv\n\x99W\x08'
        b"\x07\xc0\xe4\xa8z\xfe \x98\x91\xbf\xa0\xe2!5'\xfb^\r\xb7\xd0C\xeb\t\x0b\xf0W\xa8\xe9;\x0e}#9\xa9\xb3\x18\xac~\xc8\x8b\xc1\xedQ\xf9\xd0\xd4\xf8\x7f\xfd\xaa\xd9&4s>\xcb\xe2\x95\x8f\xf5\xf1\xe9\xff\x7f"
        b'MH\xf1\xf3\xee\xdb7\x93\x9d\x89U\xa0\x83\xae\xc5k\xf7z<\xacC\x16\x1c\xc2d\xff\xb6\xe0\x80"k\x96\xc4@\x8f\xce\xdf\x1f\x94\x13U\xd9\x85\xf5e.\xfaZur.\xfb\x84R\x0c\xcde\xb7\xa2>\xf8\x0c\xabf'
        b'\xeep\xd3S\xc3\x90G\xebi\xed\xc3\x0c49\x13$\xce \x90l\xd5\xe9\x91\xc4C>\x10\xaa\x8f\xc9\x182\xe88\x8d\x96.<\x0c\xcf"\xc3\xect\xda9`\x14*\xd4\xfb(T\xb1\x1d\xfc\xc5 \x83\xd8\xcaE*_'
        b'\x81\xd4\xb6\xda\xd3\xa2WA\xa8|,\n\xd3\xe8\xde\x9bX`\x12\xac\xe5\xd8\xdc\x8f\xf6\xa1u\x95\xcf\xde\xf7\xdc|\xde1\xa2\xec\xb0\xc0\x1f(\x8cQ\xa8R\xe0\x17\x8a\xe7\xb1\x97\xd1\x94\xe7j\xd5\x92\xeag\x14\xdcb\xdb@'
        b'h\x89{\x13\xa9\xc5\xcel\x14U=\x12\xf71j\xed\xd0\xc0L[R\xc6"&M\xce0\x81\xc0\x87\xcb\x18\xf7\xdda\xce\xadjF\x1c\xe2=\x1aK\xf3zq\xed\xfb\xd2\x89["\x7f\x96C>F)\xdf8\xfej\xe6'
        b'\xac\xd28\n\x0bN\t6s\x8f\xb2\xe6\xb2\xe27\xa0!\x88\xa1\xed\xf8{\xa6Yd\x10\xc4\xae\xca\xc8\xa1\xbb78\xddm\xf0\xad\x8d\x961\xe0(\xe0\x94o\xdcy\xe0\xe3\xba\xac\xdf+\xc4\xcd\x16\x03,\x00|8\x8a\xd1'
        b'8\xcd\xfe\x7fe\xef\xc6\x9dQ\x87\xf6C\xa1"&F\xe4\xc9.\x8f\xad\xf8\x95\xf3\xe0\xe5\x13.e\xe5Z\x9a\xaf\xaa\x99\x81\xcf\xc2\x98\xaa>Q\xf5\x1e\t\xd1\xaes$\xf0A\xa8[\xb4\x8c\xe7\x95\x7fv\x1d\x03\x90^\x9d'
        b'}\xe7\x9f\x1c\x12\x98X{+\x97\x90\xf3[\xf0\xc9\xd6\x14\xb3\x92\xa2\xab\xbd\x03a\xe6\xbd\t\xad\x9e+O\xeeQ\x0e\x8cm\x18\xd9{4I\x91{%?\xacr\xd0J\n\xec\xe3D+R\x8b\xb0\x9f\x88\xae&\xb7\xed\xc7'
        b'M\x17\xd4UQ\xe7n\xb2\xc9\x98S\xca\x13\x19\xae\xfc!f\xb1\x92\x03\xb8T\xe8\x9a\x12\xa2\xe7\x08\xa1xZ\xfb\x8b\x12\x95a\xa7dnq;\x0c\xfap>._\xeb\x97\xe6\xa1\xccW}b"X\xa0`E}\xfc:'
        b'\x9d\t\x1f\x1b\xd4\xcf{\xa0\xec\x8a\xbb\xce\xb8V\xb4\x89&Ts\xf4\xe0*\nj\xaf\x85o\x18/\xd0\xc8\xbaiDdeb82\xc5\x19gi\x1d\x82\xdeF\x83 )~\xe3\x99rgS\xd91\x83\xbe%-\xba\xf1'
        b'\x08\x86\x99T#\x1d\xe9\xd9\x8e\xbabT\xf2\xd8\x88\x9b\x1b\xcb\x95\x8f6\xd9<\x99\x82\xb7\x9d\x00\xdb\x9a\x82]\xde9\xda\x08\xf3\t\xa3\x82\xcb\x04q\xd4\xae\x06\x15z\x0f^\x89\xb7^%\xedL\xaa\x19<\xdc[M@\x8c'
        b'\x1c.Z\xea\xd1\xa2\x92_\xf9Q?}\x17\x8b\xa8\x00{\x10\x9bn\x82\xbde\xd0\xd3\xafp\xe4G*(g\xee\x19\xcd3m1s\x13\x1aY\xd9:\xe9\xcf\xcd\xf7\xf0VLR\xb9\x8c\x04%7/\xe9\x9a\xeb\x9c\xed\x93'
        b"V\t\xf2>\xc2\xc2\x1b\xca|\x96F\x10?\xffk\\$c\x1f\x0e\t\x7fg\xcd%\t\x8fr\xa1}\x87\x1boG\xe7\x06\x17\x96K\x7f8\x01C\xf4\xf5\xdf\xc8/\xf8\x18\xc1[6`\xfd\xba\xe1\xec\x8c\xe2('9s"
        b'\x81\x0e\x81\xaa\xbb\x1b^hf\x07b\xf1\x11{R\xf5\xbeV\xd6\x11>\xb2)\xf5\xf4\x9d\xb8\x16\xc1;\xeb\x88zO\x1dY+\xcc\xeb\xcdm\x87)\r\x07>\xa3vS\x00\xf5\xecm5\x90bf\x05\xe3\x85\x0btn\x10'
        b'\x0fA|@%#\xb5\xb9\xa1Na\x04\xefCK`\xf6R\xd4\x1b\xe0\xffx\xeb\xa3\x8d\xcc5\xfeO\xf0\x99\r\xf8\xb8\xb1\xa5\xbb?\x86\x8cx\xa2\t\xac\xfaTy\x8b\xd8\x9b\xf23:\xce\xe5T\xa1\x11\x86V\xeb\xfdr'
        b'\xff\x14\x99"\x85\xc1\xbe\x8ei\xc9\xb9\x97Mf\xe7\'\xf0\xdf\x16\xf6\x8e\xb2\xc3\xc6H\xd3\xc1\xa9\x11\xce\x1c\xde\xda\xdac\x7f-f\x0e\x1b\x06\x07\xca\x11\xe9\xcd\xd4\xf9i\xc9\xab\x8axjId(\x1e\x84C\x8f\xba\xb5z'
        b't\xdaK\x86\x8706\xdf\x94d\xcd\x02\x87\xa2\xa710uB\x8a\xa0\xac\xb6\xec\x96"-\xb7v\xdc\x01B\xf0H\xb8\x94\x96\xc6\xaa\\FbtA\x14\xb2\xcb{\xe5\xcd8\xb9\xe6\xd2Gm\xaa\x8a\x90\xf2<2\x8eX'
        b"\xae\xce\xc3\x17\xb9(\xd9\xb4\xd5\x9d\xb8\x05dXw\xbdv`\x19]a\xd0\xd2fmg\xfc\x8c\xd3T\xf6\xe2\x14\xd7\xcbU\xf6c\xceY\\W\xd0\xbb\x1f\x9a\x03\xbc\xec\xfcYKBato'\xa5O\xfdL\x89)\xe6"
        b'\x8e\xa6\x19\xe3\xa6\xf8\xd1\xf2\x86Q\xde\xb7^\xf9\xf5\xcc\xa3a\x01\xe7\x96\x83\x1dj\x08\xf8\x88\xdb\xc8\xba\xa7\xe6mX/\x90\xb5\x99\xd7ZY\xa2_\xdb\xed@Td7,\xbb\xb2\xbel\xe2\xf3\xbe\xd6XOC\xc1\xcdM'
        b'\xdd\xa1\xf0\xdd\xb2\x8f\xe3U\xb9\xefq\xa5l\xdd\xf8\xfc\x98\xac\xecf~\xe0!\xf0\xcb\xb4\xb2\x85vw\xa3\xac?\xa3+\xc7M\xcf\xadJ\xa2\xe1\x8cS\x1d~i\xe2/\xcd\xff\x02\x01#\xa8\x10X\x1emMQa3\xce'
        b'P\xa27>\x15"I\x85 \x14\xff\xafH\xc0\x03\xe9\xb1%\x85O\xbb\xa71\x82\xa9\x18\xe3\xe4z7y\xc1\xf2\x07\xa2(MVp\x1c\x8e\x16WE\x92\xf7\xb7\x01\xe1\n_\xca\xc0Q\x81@\x0c\xe9\xe1Z\r\x8a\xc7\xe3'
        b'UO\x1d\x03zq\xd8\xd4\xb4\x0cZ\rz\xef\x1dj\xefr\x08\xa0.\x05\xf7:T]\x16C\xdd\x1f\xca\xc9\x9f\xb9gR\xce.\xf6\xdd\xa1C,\xe0\xfd\xd9\xfa\xe5#\x0bn:*H\x9e\xa9!\x0e\x9d\xa6\xab\x14\x8cv'
        b")UWo \x8e\xabA2Yv}\r\x17\xb2\\!Lk\xe9\xec\xf7z*\xdf\x83)\xf6\xea\xf2\x1c\x12'b\xd5\x1bq9I\xcc#\xc8\xc1l\xacE_\x8a\xcc\x83\x8bM\t\x94\xac\xbd\x83_\x14\xda\xc8TL\xd3"
        b'\x83K\xbc\x95\x06d\xe4\xfb\xe9\xd3y\xd4p2\xc0n&\xd34\xd9l\x1b\xa0J\x87<\xa159\xe6a\xf9\x85\x9fQ\xdb\xaf\xc3\x9a\xc6-\r\x8e\xeb\xe8\x9a\xcc\xbf\xf2rOb\xce\xfb0\rp\xbc\x15\x8a\xa8\x05\x85f'
        b'\xe3\xaf\xa7\x119.bU8\xdc\xf7S\xa6\x8eh\x9fH\xd7\\\x8e\x01i\xa7c\xd4-\xb8?f\xe7\xb1\x94\xf6\x83\xe9\xb3\xe8\x8c\xd6\x93\xc2\x88\x90\xef\xa7\xd0\xccT\xf4\xde\xcc\x8b\xd7$0\xcb\x9d\xbdh\r\x82Q\xd8\xcd'
        b'z\xd0\x92\x1d\t\x1cd\xb4\x0b`\x96Xg\xad\xcab:\x9f\x1b\x9b %4~\x98\x86\xf8\x8c\x07.\xa3\x1bm\xc4\xdb\xcbA}\x02C\xfc\x01Z\xe1\xb5^\xd9.\x96u\xb4gk\x11\x81q\x14IU\xc6auQ\xe9'
        b'72n\xc37\x9b\x8f\xfa\xf5\xea\xedo8\xff\xe2G\xec\xd0W(\x90\xf2CwD\x9c\x94d{wf<;\xdf\xad\xe9.\xf39\x9e\x1d\xe9Ds~=\xe2\xa2\x85\xc6\xdd\x1d1\xe7]\r\x97\xaa\x82\xf1)b\x165'
        b'8${\xcdH;\xb2\x89l;d\xf6\xb8\x19\x00\x14\xf6\xb3B\xaeSsP\xff\xa5\xdem\x97\xdc8\x88\xdc\xbe\x11\x10z\x19\x0cc\xcf\x00\x86\x81\xf7\x85=hL+\xd6\x97\xe17g\xb0\xe1a\x0cA\x86T(0\xe5'
        b"C\xdeZ\x84m\xa9\xde\xf3xVa\x80\x17?PQ\xd1\xaa\x06\xf1\xdfOn\xcc\xedH\xaa\x89@h\xc9\xbfNo\xb9u2\x08\xaa\xdd\xa2\xf8'\x7fmN\x11\x87.m\xdc\x95\xda\x0ckO\x98\xb0\x16\xa9X3\x92\\"
        b'\x06P\xc9\xb3\xf2\xcb\xe7\xac\x87\x1eD\x13\xc6\x01\xda)\xf5;\x86\x83u\xf9\xd0\xb7`R\x0c\x973\x83\xe8#\xa9\nI\x99Kp7\xd8\xbcE\x00\xba5rP\xc3\xaa\x9f\x02!Ig\xe3\xe6\xcet\x9a\xe6\xfb\xe7 -'
        b'\x88\xb0\xc3tw\xa0\xfc\x0bA\xe2\x0f\x0f\x8e\xeb\xdd\x90\x9e_\xcd\xb8\xd1\xbc1\xc1\xe4\x0c\x94\xc3T::\x1bJ\xaa\x08 Ub\x8a\x86A\xd0\xc5\xce\n\xf6\x14\xd0\xd4\xce<\x82\xc6\x15K:\xbfk\n!\x82\xbe\xa2/'
        b"\xddx\xa7\nm\x84\x9c\xad\x03\x90\xe5S\x8c%\xa3\xb3\xf7\xfb\xc8\xce\xcd\xa4Kc\x04'\xe0\x07B3%\xd4\x1cZ&8B\xe1\x03\xc1d6\xe9w2{\xfe\xd1\xd8\x92[\x12\x83\xe5\xccq\x85\xc0\xe2\x8eG\x94\x81\xb6"
        b'\xb7\x9dG\xc0\xb7\xde\x8a\xa5B\x0e|g\xbat\xbc\x8c9\xd5\x83\xebC\x1e\xa9\x179\xf9\xe3\x90\x05\x86\x15\xe0\xf4\x1ees|\xb2\xa4[g\xec\x05\xa3\xc9\x15\xeb\x00\xb7# \xaa))jKL\xe4\xa1\xce\n\xe8\xa4\xa2'
        b'\x11\xfbf\x96\xaf4_\x0c\x1d\xce\\\xe7\x8a\xa3\xc1\xabV`\xdch\xd6I\xd1\x9a1\xbb\x10\xf2\x88\x8f\xfe\t5\x8dx~\xa4\xa5=w\x1fS\xe6\xfe\x03q}\xd8\xe2A\xfej`\x87ql\xee\xe3\xf9\x13\x9dp\xac{'
        b'\x95h\x9d\xf8\xae\xb5\x08\x93\x08\xaf\x8a\xbd\xd3\xc7c[%\xd0\xa5Opg\x8c\xaf\xb7a\xedF\xa2\x97p4\nc\xbf\xad__\xe1\xce\xa3\xb1\x15I\xb0%\xee]V N\xc2\x93\x05N$\xfeM\xcfl\xb7\xe4\x1du'
        b'\xe1\x9a\xf0]\xcc,c\x89\xab\x97\x8f\x95i)\xbd\t{\x18\x7fVUo\x9ah\xe8)\xdd\x92@\xf0\xc6\xf7I p\xc7\x158\x89\x15X?\xb8\x1e[\xca1\xdc~B\xc7D\xb8"k\x1b\x7f\x92\xef\xeeH\xb1M\n'
        b'\xed[\x8d\xa1\xdeK\xba\xe8\x10\x05\x11\xde\t\x8c\xcb\xc5\x8dJ\r\xd6Me\xab\x02^5\x84\x96\xdbh\xf1~l\x189\xb3i \xad4\xb2c\x9e\xfe\x870G\xed^\xab\xfdu\xacS?=\xc4P\xa8\x8er\xe8\xbc\x11'
        b"\xa4+\x85t \xce\xb0I\x92_\x83\xdc\x8b\x07\xb2J/+\xe6\xd5E\x04\x98^\tJ\xe6Gc>\xc7D\xdd\x1e-+'\x16\xb2\x07\xa9\xc4\xf2:\x1fL\xcd\xe9\xaa#\xd1\x1aD\x9a\xac\x95\xca\x14\xee\x1f\x88\xb9\x15|"
        b'\x87\xbe`\xed2\xb6\xbb\xa9G\x81\xab\xf0\xbals\xcc$\xe5\xea\xaa\xe8\xcdt\x84\xf5\x86a+\xef\x15\xacP\xd6\xbck\x0b_)G\xf3!\x1d\xe7\x9f?J\xaa\x8c\xfdT\xc7[gd.\xcd_c\\\x1a\xb0\xb9x\xb2'
        b'\xab\xaa\x10d=\xb4\xd7\x9f\xa5@\x07\x01:\xe4\x94\xe4\x93\x1e{\x83\x89J\xba\xd3\xedY\xdbO\x80moL\xb7\x0c#\xa6\x04\xce$\xce\x11\x9cp\x1ff.\x9c\x83\x939\xbc\x8a\\W\xf7Es\x0f\x90e\xa6f\x16\xa9'
        b'\xa1\xc4\x92c\xeb\xfcvdw\xde\xcd\xb5\xfe\xe4I}\r\xf4\xfdi*<\xb6y\xc0\xc9\xe3N\xc6\xec\x83\x91\xedY\t\xfbP\xbd\xd9\xde>\xd3/Y\\\xf1\xbc$\x0c\x83\xd2K\x9d\x97\xdd\x97\t\xb4\x03o\xa5\xe5\xba6'
        b';v`\x94Wx6(\xc6wCK\xfc=1\x84\x9e\xf2\xfc\xa3cFI\xf55WxN\xb4\xf54\x0c\xc8w!8R\x01\xd0\\MT\xf7\x80\x97\xe2\rK\xe8b\xeb\x81d\x19F9\x0b\xcf\x9f7\x85]\x1b\x0f'
        b"\xbd\x07\xde\xd1\x89\xca\xe1\xf4\xbb\xad\xc8\xdf\xfb[\x86\xfem~`\xc0+\x9e:\x9b\x1b\\'\xa7\x80\xe5\xf6\x1c\xfeu\xf1\xb2\xf87\xfb\x1c\x9f\xc7\rb\xd9\x9e\x82o\xd6\x03\xcd&7{+\x1e\xac\xaa\xb6\x1f\xe1\x1f\xb5\x9c"
        b"7\xe3\x93qMZ(\xd0\xf2\xff\xbb\x02\xaeG\x0fG\\\x17h\x1e\x12\xc4\xe4\xeb':\xd0\xf7\xb1B\xf8\xd3\xd9\xdc\xa4\xbb\xef\xd7Re\xfb\x1e~H\xbd\xd1U}\xe2\xf7\xc4\xe0*\xea\xe1\x81\x95\x14]\xf7\n\xbb\x9a\x92"
        b'z[\x85V\xf68\xd5\xc9Q\x9bAL\x9d\xa29\x14\x96&\xa2\xf3\xffa\x98\x18\x9f\xcd\x064\t\xe4!ub\xed\xd5\x86AQ\x94D\x14\xe4-4\x17\x80\x7f\xa6\xfa\xb8|W\x93ZYB]\xbd\xab\x81\xa8\xfcy\xea'
        b'4\xbd\xb8\x90\x15\xa0\xa0\xeb\x9a\x90\x86\xdfN<\x86NI\x90oC\x04{\x1e\xe1\x90y\x1bc\xe2G|\xcf\xca\xf7\xc2_\xf0\x19\x85\xd4\xba\x16W~\x1d\x1c,O \x80\x1b\xb5\xdb\x7f\xc44\x05\x90\xd2\xec\xf2K\xc4\xd2'
        b"s\xf4\x7fy\x96X\x17\x97\xffJ6\xa7\x86\x11\xa7E,z\xc9\xdet,\xbf\nR}~\xe8R\xb81\x139(\x05i\x84\x92\x85\xb2w\xc9\xca\x18,\xc0e'\x1b/\xb89\xfb\x1c\xbc\x9dTD\xc3%\xbb\xdb\xd3P"
        b'\xcc\x13\xcets\xc66\xbb>\xe7o\x8c)\xbb:\x91\x8f\xba\xf3\xd9\xb1\xbcr}\xbe\x13\x8d[o\xb1\x10\x8cY\xf1_\xe1\x0b\xc2\x7f\xe4:\x1e\xefG\xacU\xe0H\xcf"\x99\x15\xb6|\x18\xbf\xdc\xa2\xbf\x82\xdd\xa1o2'
        b'i\x0c:V\x10\xbc\x8c\xba\x8e:\xa3\x16\x1f-\xc1\x8d\x06\xbc\x16P\xf0\xd6\xec\x8e \xf3\x82\xe2\x82hon-j\xc6_L\xa7\x0f\x827\x04\xcd3\xae\xff\xacF\x03I|+k\x05\xd8\xf8M\xe7g\xc3\xe2\x7f\x8bc'
        b'\x88t\x0b\xb2\xa3_\xb7\x05\x88*\x0e\x96.\xb3\x05f\x92\xb9\x12\x158\xa3N\x15\x91S7A\x9dZ\x84\x15^gbJ\x8c`S\xb9\xf1\xea\x182(\xdf\xa3\x8d,R]\x84:\x13\xef\x906\x9d2\x93\x89\xf4\x86\xd5'
        b'\x10\xb9}\xd4\xeb\x91\xde5\xc0\xe3\x9d\x059|\xf4\xf9\x00j\xaf,\xa4\x8a\xde\xc7\x0b\xfb\n\xb7]\x96\xafK\xaa\xb04\xf4\xec\xfd\x0bb$\x10Fx63\x8a\xa3\xbf\xa6\xac\xbe1\x01\xf3\xf8j\x17\xb5\xd2\x8d\xdd\xac\\'
        b'\t\x03\xe52\xa3M\x82&\x17\x05Y|\xf5\xfe5\xf7\xa7\x9b\xd4\xaf\xba\xfc\xbe[$\xc4#\xe9b\x12\x97(@\x8c\xcc\xe6\x80\xa0\xc6\xeaH\xa3\x0c~\xdd\x03d%p\x91q\xf7\x18\xe9\x8c\xcam\xe3\x80#C\xe8\x88\xc5'
        b')T6~\x17\xd0}\xfb]i\x1c\xb7\xdb\xe8Q\x0b\x12W#\x83\xef&\x90\xa1]\xb3\xf5\x8dg\x0c\xd2U8\x04\x17\xa7\xe5Q\xd4\xad\xe5.B\xd4P\xd3\x1a6\xdf\xf5\xbf\xb3\x00n\xedN\xcf\xe5=\xd2,\xac\xad\xe6'
        b'\xfb\xae\xbayh\xd9A\x8d\xfe\xdbsHJ\xd8\xe3L\x00\xb3\xe6s\xcb{\xe9\xd9Q\xc9\xc3\xe9<\xa6]\xe8-k\x1b\xa3\xf4\xbbFVp\xe8\x10\xdd\xec0\x94\xef\x92x+CU;r\xac\x11\tc\x90v\x18\xf1H'
        b'Z\xcb\x88\x95\xce\x07-\x05\xdd\xbcb\x9e\n|\xf5T\x02:\xc8\x93\xae"\xf2\xb1\xa3\xfd\xa4\xde\xfc\xd2=Y\xfb\xb1\x83\x85f\xf3\xea\xe4f\xdc\x1c4\x85\r\xdb&\xdf$\xc0\xf3x\x9c<\xd4\x05o\xbdm\rEE]'
        b' 0\xe5X\xf7\xc32\x8dg\x15\x847\xb8\xbf}\xc3\xd5\x9d\xc1\xb3&\xc5\t\xb5L\ts\xca\xa0G\x83\xb4z+n\xf6\xc8?Wf\xeb\xf3o\\\xf5jbY\xfd\xf2\xbe\xd3\xa9\xa3.\xab#\xdb\xd3\xecbJ$\xd9'
        b"Yc\xd9\x07\x04\xbe\x81\xf9\x1b\xf0\x9ct\xbc\xdc\xe6\xf6\xafkk\xed\xd4i(\xf1\xc7\xb3H\x06IM\xee\xc7`$\xca~\xc6\xfa\xfc\x87'Q[\n\xc7~\x10\xc0\xeb\xbe\xec\xc8\x9dg\x97\xbaLa\x9e\xccF\xe8\xfc\x18"
        b'\xe2\x99E\xca@{\xfe\x9c7\xbf\x84\xb3*\x18\xc9\x9f\xbaEl\xdd\x93\xc8q\x8a\xc2\x9a\xdb\xf0\xd1A\xd9\xcf\xcaQ\x92\x92\x1dh\xbd\xf0\xcc\xa6\xe5\x089*\xc1m78\n\xafbF\x87\x1ah\xee\xb7\x1a{\xe1\xfd\xd0'
        b'\xe9\xb9\xc9\x08\xe3W\n\xae4\xfbC{h\xe61L\xf2>\xb7\x04G\xd1\xd9\x1c\xfa {\xa6=k\xffT\x82L\x90\x9ds\x07\xd0F\x14\x02\x89\xd3&\xac\x92h\xe6\x1a\x18\xe5\xeaz=|\xedVO\xa2\xf5\xa5\x13.'
        b'\xe5\xf0 N\xb9\x81CP@\x07\xd4\x01\xb9\x17\xeb@\xe8\xda\x97\x14\xd9\xe6\xcf\x9a\xd7\x86\x87\x9el\x8a\xacy\xff\xfa\xda\xb8\xb4:-K\x06\xeb\x80\xfe\xe2\xedFam\xc3\xe9q\xf2\xff8\xb8\xdf\xad\xd6\xc8\xf8\x00\x14 '
        b'\xc5\xe8\xe61\xb4\xa0\x9f\xd06w\xc3\xbe\xd0\x1b\xb0/M\x914?\xeb\xdb\x8b`\xa2\xaa\xdf\xe5\xb07<;;\xf8%\x9b\x06\x9c\r\x98c\x01c\xdeN\x12\xd6z\xe3s\t\xcb\x04\x1f\xe8\x90\xf4\xff2\x03\xc9M\x0c\xd8'
        b'N4\xe7F}\xe8T\x9a\xddD\xcc\x0b\x01\xcfJ\xf8_\x80#Ra\x08\xa1\x92\xb0\xd0D|j\xfc\xabA\x14\x0fzu\x16\x12\xe2\xbb\xca\x0eb-\xb09\xbbT\xe3\x9d\x7f\xaa:\x8b\xd6\xb4\xc0\xa7\x80\xdc\x1a\x9d\x7f3'
        b"x\xb4Z\xba\x9d3\xe4\x17'Y\xa6\xe7\xa3\xcc\xe3\xf8\xd7\xa8\xb3\xadp\x97\xffx$\x1d\x99\xbc#zG<\xf4\xe9z\xd0\xffk]\xea\x90+;\x9c\xcb\xf5Oc\xa4\xbe\xfc\xf1\xe0\x08Vm\xe5\xb5\x13\r\xb2]\xc2}"
        b'\x1e\x08(\xd1\xc4\xc6\x05CjK\x19\xad\x8a}{\x98<s\xa7\x06\xdf\x97-\x8dz\x9f0\xf8\xae2\xa1\xb5\xdaa\xe4\x16\x19F\xbb\xce\x0e0k\xa3\xe4|KD\xc0\x1f\x18I\x1e\x81@"2\xd7\xear\x0c\x06Rp'
        b"\xce\xc6!\xf9\x92x\xea\xcc\xb9dv\xc9j*|\xe73\xd59\xc2)q\x18^\x1d\xda\xa3\x05\x10\x97\x12Q2\xb5\x14\x03\xa3\xae'\x14\x19\x94\xf6\xd7\xc4\xf7V\xc2`K\xdeg|XPjU\xb4\xd9\xcbs\x04\xcf\x81"
        b'\xf0\x0eMDX\x86\xb5\xedU\xd5\x81\xb7Yb\xd4d\xf9\x8f\x82\x0e\xc3\x1bw\xe8\xf5D\xea\xd1&_\xd4\xaaVG\xb8\xf6\xfdc\x94\xef\x03\xeaX\xea\x86q\x12\x97\x92\x87s\x90\xca4\x16\xde)U"\x9c>r\x80\x88'
        b'ET\x1f$\xd4\xb7[w\xdcgr\x83]7\x0f\xdb\x96\xe2\xc5\xd10&\x83l&V\xc6%sM\xb9\x8c\xd4O\xe7\x1d\xd7>\x96V\xb5\xce\xbe\xab\xc4\x84o\xc9\xec\xcc\xecE\x94\xc4a?\x14i\xf3\x11\xf1s\xd1D'
        b'9\x8e\xaas\xbe\xffc{\xb4\xee\xf2\xfd<i[\x0e\x0e{\xb7\xcc\xbb\x02\xff\xd0\x90\xf9ZVr\xa3\x10\xbe\xfa\rb\x17\x9e\xcbL\xa1\xb5\xf8u\r\x8e\xf6\x1e\x96Z:\xc7\xe6q\xc8j\xac\x7fGZ\x1e\x17\xd2v\xe0'
        b'\xeeYA\xc3H0\xff:\xf6!/#\x06\x96\xae\x8a\xae\x02\xee\xdaC\x1d\x90\xa3\\\x84\x16\xcbn\xe0}\xf85\\$\x03g8\x8a\xc4^}r\x0b\xc8\xe2y\xa8\xe7m\x88\xd8\x1e\xd9P\x12\xe0\xd6\xdeE\xf1\x0c\xd6z'
        b'\xc7I\x8a\x93`\x8a:=*C\xa8\xef\x99w\xa2-\xf20w}\x14\x03;\x06[\xef\xde\xd1\x00wN\xbb9f\xb4\x15\xe2\x8d1\\!e\xa8\x91I\x9ee\x08}"\x1e\x0e$w\x9d\xd7\xe3\xcd;\xc6\x1e\t\xadE'
        b'\x1f)\xea\xdd\x19,\xe3[h\xa7\x98:\xde\xee\x7f1\x1f($h\xd7\x02\xbeM5\x06|\x87\xdac:\xaey\xec\x16\xae+\xdb\x1bK\xb2z\xc4}2G0\xbc\xeb|\xc6\x970\x81])\xb7\xad\xa6\xc2\xe3\x02\xe7\x9f'
        b'\xcb\x90!\xdeN\x0f\x82YZ\xe1_?ol*-\xdb\xe8(d%\xb1\x02\x9b\xb2\xd5a\xbc\xa5!\xf7\xf7\t&\x04\xee&\xdd\x9b\xae\x02P\x12\xc3U\x90\x08d\x11\tKq\xc4\x02\x8c\xc6u\xb3\x95\xc1Q\xf3\xa1\xc3'
        b'i\x14\xf0QRhL\x84\xe4\rW\xc8\x9e\x14\x99C,C\xef\xc1Cz\xf2\x97\xc8\xc8o\x17\xca?,\xcdUi\xd7/)>\xe3|\xc5\x909\x07\x16\x15\xc1\xa9\xc7\x1a\n\xbc}jv\xeb\x92\x15\xe0\x94U\xca?}'
        b"\x1ftT\xc7\x99\nU\x1f<\xdc8\x18\xf4=8)POJ\xa6r l\xf1\xe4\x1c\x1f)\xc7\xc2\xdc\xef\xf5)\xd4\x11L\xf52\xaf\xb09(\x9cS\x87\xca\x90\x95x'\xcd\x9f\x9f5-~\xfe!C\r\x0c\xb2\xba"
        b'\xa8{\xd0\x95\x80\xa9\x19-\x17UP\x1d9&\x8d\x929\xda\x14\xbb\x97\x9ew\xb9\x01\tEW\xcdoD\xde\xdb\x0b^\x14m\x15\x9f\x0b\x85\x0f\xcb\x89\x15.\xfa!\x86\xe7\xf5\\\xe0G\xcf\xad\xcc\xf8_\x15\x0b\x12\x94\x1e'
        b'\xe3\x90c\xf3\xfd\x9f\x96\x05\xef\x06\xa0\xca\x13\x94\xec\xb5\xa9Rtv\x866\x8e\xc6e\xdc\xf1|\xf5\xf2\x0c\xb8^J\xa8\xecc\xd6n\xb0a\xe5\x11\x06\xb8\x92\x92zH}\x8d@;{\xe2\xd2";\x13\x8f\xf9.\x8d\xd1'
        b'\xe5\xeem\xd0\x85\x93\x03\x1fW\xcaSa\xf8\xd8\x1d}%\x98\x17\xde\x04\xf6x\x16\xdb\x0f\xd0\xf2\x93\x91\x82\xb9\x86\xa7E\xea\xdd\xef^h\xfaT\x9f:\x08b\xaf\xf1*\xe6\x9c\x07\n{\xe7\x0e\xcf\xfe[\xce\xf3h\x10\x19'
        b'C)\xa9\xe1\x8a{\xca\xb5\xb2\x82\xa5\xba\xb7|\xb5\x85\x9e\x1co\xd8\xd8EMU\xcaKP\x95l\xae\x90\x13\xfd,{L\x8aSu)\x1a\xfd\x08WWI\xa2$1:\x07\xb8g\xceq\x00\x1c\xf3\xa3\x86\xe5\x93\xc5\x1f'
        b'\xd3\xf7qk1\xae\xd08\xad\x1aF\x97\xb2GN\xaf\x13\tv\xc7\x99=\x15:I\xa7\xb6\x88\xc8X\xa7\x8fU8\xf4|\n\x89\x87N\xfc\x9c\xb3\xf2 \xf5\xd2\xa7~\x91^\x9c\xec\xc6\xce\xf3\xd2\xec\xe9\xfa\xa6\xcc\xebn'
        b'\nF\xbf\x9b\x1b(4\xa8~?U\xcc\x8f[\x8c\x13\x97{\x82y|;P\x8c\x1c\x8f\xb6"\x0b\x89)\x1ct\x88\\\xe13\x81J\x95\xae#\x91\x957m\x8c\xec\xf84\x7f\xe1K\x9c\x03\xb9\x8c\xd4\xfb\x92&\x9b\xe6\xa0'
        b'Xb\xf3\xd5\x89P(\r\xabxhP%\x18\x1b\xff\xd1e\x0bM\x8b\xcb\xd70\xc0Vv/2\xc3\x1bgB\xc2\xa8n\xf1Ca0CX\x83\x85\x96<\x86c\x04\x06\xad_-\xe1\xa8b\xab\\\xe0\x02I\xf06\xbd'
        b'\x05c\x91\xda\x02\x0c\xfd\xb2[\xca\xaf\xa1\x18F\x08\xb3`{,fl6?\x00\xd7\x14E\x01\xa3n\xb0\xf8_\xe5\xaa\x93k\xbdYB6\xf9\x85\xe1\xf6\x07\xe2\xaa`F\x953ew\xd5~\xce\x122\xcc\x05\xd3\xc8\x97'
        b'\xa1\xae\x19\xaf\x90\xb7@\xac\xdd\x84\x862\xce\xc0%\xc2\x80\xe9\xfe)\xdbO\xd8\xb9V\x94u\x17\xba%\xd8(\xaf\x01\x9c*9\x8d\x07Y\x91\xd0GH(q\x12\x05iY\xe4\x9c\xff\xd7%f)\xf1\x8f\x95\x0e_\xa6\x9c'
        b"\xc1\xd3\xa2V\x91\x16\xb4\x93\x18\xb1*\xd9\xfe\xbf\x83\xd2\xa4\xafLG\x85>\xf2\xaf\x9bK)\x91\xdc\xccM\x90M\x80\xf5x\x0e`v\xd2\xbdt\xc2\xf1Uo\xb2l|\x9e\x1a4\xf0`'\xa4\x90XV\x9bv\xb6i\x1b"
        b'Y\x16\xd9\xaf\x9b\xd2-`*\xa1\x97DKw\x9b\xb4\x16[\xb6S~\xe5 }\xfe\xc0IR)\x1e5rvUz\x9c\x00\xf6\x01\xe1\xeb1w\xff\xa1U\xd8\x834/\xdd\xd2\xdb\xad\xd9\x82|\x16B\xaa\xc1Y\xef('
        b"e\xc2\x1e\xffO\x1dO\x8b$!6b\x0f\xf9\xbaVT\xf8\xd29\xe9\x91 \xb4S/\x10O'\x8d\xd4\xf2\xe6\\\xe0\x12\x01\xb97\xe3\xf4:1YC\xd0\x1a/@H\x8d\x02\x87H\xb4\xd5ht\x85\x95V8\xd4;"
        b'\x14<\x01\xb7\xdb\xc1p\xfa\xdbh\xdb\xea\x15\xf8F\xb7\xc0aU\xdbX\xd0\x87\x1e\xa6\x81t\x03:\xeb\xe1\xb7\xa9\xeb \x1f9\x8f\xc2\xcd\x8d\xcaA\xa8\x17\xab\xb4e~C\x12?\r\x03Y\xa2\xfbW\x01\xbc\xf1\xed\xd1*'
        b'\xe3\x12\xcf\xe4\xe2\x8a\xf2\x912\x8d\x12W\x862\x9d\x81\x0eZ\x8f\xe9\r\xa7_q\xdf\xe6\xc7\x10X\x12\xd5\x9c\x07\x1b\xd18\xed\xca\xe2\x87L\xf2\x92\x13\xbf\xca\x03,T\x14\x9c#h\xb5\x1ab\xd0M\x12\xac\xdc(:I'
        b'0\x18\xd1*;:\xc1Lu6\x00\x89\t\xc6\xdf\xbb\xc2\x83-\xa5\x9c\x96\xb9\x8a\xc9\xd0D|\x19\xed\xa76\xcd\xca*{=|\xeb\xc4\xc7\x9cw\x13k\xd1_\x1a\xd0\x950\x95m\xa3\x9ebN\xfe\x8e\xee$l\x0f\x19'
        b'\x8d\x9bS\xbf\rLFS\xeeeG\xe5\xcd\x86c\xc8\x81\xbfuy\xb8\x94\x16\xfb\xa6d\x88\xb8\xa14\xd0H\x9ew\x00\xd3\xa1\xe85\xc3\xa5\t\xc0\xffC\x1d\xdb\x87\xb1\x97\x8f\xb0\x02W\xc3\xef\x0e\xc1hO\x9c\x8dP\x08'
        b'a\xaab\xe8\xd9\xed\xa6\xd8\xec\x1c4\x0bh\xca\x99\xd2F\x8c\x817W\xb4\x8dH\xb5d\xbe9E4\x97f\x06b\x15\xc9\xae\xe1A\xb7*\xff\xbc\xf9\xd1\xa9\x86}\x94\x9b9\xe2\xdbWg057\x10\x85V\xa0\x98\xc7'
        b"\x95'\xf6\x16/\xa9\x12>A\xd7_G@&\xc2\xb6\xe65Pt\x1d\xec\xcd\xfc\xacQ\x94\xe9Y\x0cj\x17\xe9<\xb1 \xe5\x01\xe4p\xdd\x8b\xf4k\xa1\xbe\xfd\x08>M\xe7s\xb9\xdaf\\\xcaX\x9f\xc0\xad\xe0V\xe9"
        b'\x04\x16\xe7\x03\x1a\x81\x0fY-\xe2)\x91\x0c\xd2u\xe3\xc2\xf6\xefH\x84z\xbf0\xe9\xa4\xc2H\xad"\xb2\xc1e\x13u\t\xa6o\xb2_3\xcf\xa9\xd5\xb2ssK\xe3\xcd\xcc\xd8w\x19x\xf5\xe3\xc3\x02\n\xf3{\xd5P'
        b'\xae\x18ti\xdc\xd7E\xb8\xf0\x9c\x8c$\x87\xbcJdx\xe1#\xf1\xaeP\xd0\xa5#<\x8d\xc3v\xfb\x921s\xbd\x0c\x08\x93~w\x02\xc9\xd3\xe5I\x91\xf9\x9e]\x99\xb13\xdd\xc8K\xd3#>\xe7u\xe2\xf4\xfe\x9a('
        b'\xc12\xe6R\xe1\xd1\x8d5\xc9\x8d\x1d\xe9\x19\xda\xccn\xa4p\xdc\x01\xa4h`\xd4\xc2d\x91\xd01\nP]\xe2\x9cD5\xe4F\xcfP|}\xc8\x170m4\xa1\x13p\x1a\xb6\r\xb9f\xa7\xfc\xddJ\\\x90\x15\xcd\xdd'
        b'\x8aT=-\xca\xd2\xb9\xcc\x14\x8fI\xfe\x87bq\x05O\x1dn\x97\xc48\x1e2\xf4:;4\x01\xcb\x90m\xbba\x15\xef\x82\xb1\xb8|\xe8\x91\xc3V\xf8\x83Eh\xfcF\xa5\xde/|\xa7\xed\n\xdd-\xa0\x0b\xd0\xad-'
        b',[\\\xa3\x95\x03\x05\xcd\x0b$\xbcF\x0e\xa6\xf2\x16S\x00\x0c\xb8b)$\xfd\xb4\xb5\x880]O\xc3T\x97(\x0fp$\xd2\x8a\x00\xf0\xab\xd6\xb0\xe5\x83\xff\xc8?\xf1\x8a_\xb2s\xd90aV\x0e\x1cdz\xeb\xd3'
        b'~\x8eh\x81\x03\xd9=1*\x16J\xb9\xacz\xb0}0W\xd1\xd8@\x95\xbdUX8o\xf7\xe1\xaa\x05\xa2\x02\xba\xe5\x9c?\xe3\x00\xf6YP\xb1U\x8f\xa7T3\xa6\xb9\xa9\x18\xaa\xe4\xfbU\x8b\x83r$\x95k\x99Q'
        b"\xbcK\xbb\xff\xbf\\j\xc8\xa9\x90e\x92\xce\xfdW\xc4\x99'\x8bS\x11H\xef\xfe[\xbe\xc2\xc1q\xdf\xac6z\xfc\nT\x8cR\xbb8I/\xf3F_z2\x83\\8\\\x91\x99\xfc\x91c\x01o\x14\x95\x1e\\\x84\x8b"
        b'"-\xe1\x8f\x02\'\xbf\x88O$\xa5Z&t\x8f\xb4K\xd5!\xda\x8a+\x93\xda\x80X*\xa5\x9b\x97\x14!\xa3\xb5\x16\x0f\xcec\xfb\x80\xe1\x0c\x98\xb2\n\xeb\xa8Eq,!\x83]B;\xf9\xb5j#7\xca+\xd0;'
        b'\x0f\xeeg\xac\xe5\xd3\x1d\x81\xc9\xc5i\xd3X\xdf\xd8zI\x9a\xdb\xe9\x8a\xc5\xff\xc2$7\x80\xc9*\xdf\xa7\x87\xd9\x9fQ\x8fY\xd8\x95\xe1\xb6\xf7\x02\x11c\xf3(\xe7\xbcu\xa0\x1e<\xc1\xa6\xb9/]\xc1\x80\x0c\xfb\xcf\x8b'
        b'\xbf\xc0I\x13\xe2UA\xc9c\xbbD\xe7\x0b$\xb0\x8b\xf2\xb3\xf8B\xf2\xdb%\xe7 $QBC\x1f\x81\x05\x0b\xc7\xf4\xc8H\xcd4<{a\xa2\xe0\xaa\x02\xc0GY\xa5\xa6\x08\xd2\xfdA\x82\x11\xa4_@\xc6E7`'
        b'Hg\x86\x1c\xef\x82\xb9G\x02\xe0G\xd1\xd7]\xdfO\n0P\xd3\xe1T\x17ScQ1\xec\xb7j\xd2\xc9\xb5\xdd\x8dML\x9a\xf3E\xf2\x9c\xca\x9e^1y\x86s\x18?W\xf4-\xcb\x14\xe5\xb0\x94\x9c\xa0h\xbf\xd6'
        b'\xe2\xdf\xfb\t|\x16\x0crn\t\xb8"\xad\xc2\xc3j\rA\x17\xf2X\xaa>\xfb\x94R{\xfb]<Me\xcc&\x89\x17\xa9D\xa9\xdb\xa4$Z\x93,+\x9b\xbb\x9dEw\x03gY`\xc1+\xb1~\x8f:\xef^\xc7'
        b"\xc7\x1ct\xffPws\x87\x02\xb0c v\xcc\xe4\x0f\x82\xae,\x839\x9f\xcbs\x01\xe3#!\xba\xb6_'\x06\x87q\xcdf\x03oc\x19\xc6 H \xf41\xe6i\x8c\x99\xb3O\xf9\xde3!U^Qi\x8e\xb4\xa2"
        b'K\xefnb\\\xf6\x1a\x08F0\xf3\x8e\xd72k\xb3P\xa5+\x89t\x05/\x83\xa7\xb9\xb9&\x83e \x8d.\xa2\x9d\x14Ao\x1b\xbfB\x81mh\x00\x03\xd7\xe4\x8d\xf2m\x99Wf\xa5B\x05\xf4\xed\xb4\x89>\xbe\xe2'
        b'\x08\xc4\xdf[\xac\xfdZv\xd8\x02\xfc\x17\xa4\r\x08}\xd8WY3\xc3\xf0\x11F\xa9P\xd5\x010\xc3\xb9\xad\x9d\x99R\x0c*\x95`b\xc6\xd5\xc1\x8c\x98\x14\x9b\xac\x99\xc6\xb2R\xebu\x16wn\xfdhQi0\xb9\xbd'
        b'4\x80\xa0\xd6\xbd\xcc\x0f\xb7\x9a\x8bA\xd3\x1f\xb5}mk\xab\x88\x05d|\xc4\x9a\x1dH\xbe\x94\x88\xa1\xa6\xda\xed\n\x1f\xff&x1\x99IU\xe9\xb8o\xfa\xc7M\x91f\xeb%\x89\x1d\x1f\x87t\xcf\xd9=\xe1\x90\xfd\xc6'
        b'\x06\xe1\xfd\xb3\x9a\xcd\xb6\x12\x1d\x9b0ui\x8d\x13{\xea\xa0 \x07\x9dE\x0e\x1c\xdeur\x08F\xf7\x9aN\xd0.\x1b\xcf<\xfb\x97-?b\xc2\x1c\x1b\xf3\xb0\xb8\x84kT\xb0>\x02/\x0bo\xaf\xd1S\xfb\x87\x81\x0f'
        b"\x9a/g\x13\x11\x94\xd8\xb4Q??\xc54CX\xca\xa2Z\x95\xdf\xa1YX%K\r)\x91\x8c\x88\x15\xd7j\x83\xb4\xd2'\x1dG\x10!\xfc1\xd2\xc1\xf8\tB\xb7\xd7\x7f\\\x13\x1cBp\xaa,9\xf3\x0b\xb5M\xdb"
        b'\xe2>\xf15/+\xc6\xc7\x0eI~HJw\xc5O\xfa\xfeEW\x07\\\x14@\x8bb\xaa\xe2\x95\xd0X\xbf\x9d\xe92\x8b\xc1k;\xc6\x0e\xe4\xa7c\xc4\xc4b\xb9Q\x1b\x9787\x96Y\x98\x06\xfb\x81\xc5\x8f\xd6)\xda'
        b"\xbd~)n\x9b\xf8\x97\xa5x.(+&<48\xaf8j\xbc\xd5iZXk\x0e\xcb\xea!\x83\x8d\x1dA.\x04S\xed\x12\xe9\xa2_.\xd8\xea\x9aC\x97\x94\xd0\x87Z'\xb6\xea\xb2'\x94n\x9d'\xda\x92O0"
        b'\x80\x0bRL4\x9d\xf6\xf9\xe9n=\xf9\x8e\xdd\x00A8/\xb1{K\xb0\xfb\xeb\xa0\x8e\xf2^\xda\xd3\xab\\\x07&\xcb@~7_S^\x84#-\xdc\xf7\xc9\x0c\xa2 \xde,\x9b(\x06\xfe\x87\xdfg\xa9ot\xfc\xc6'
        b"'\r\xdfR\xd3\x9b\n[\xff\xf8u\x87\xeb\x97\xa6:\xb8\xfb\xe6\xfd\xda\xc7H\x91\x92pv\xf6b\xee6\x02&2t\xa0\x93\x11\x88\x16L\xdc\xd2n\xe0\xe6\xa5i\x11\x88\xa0>8\xdb\xa0\x15\x873\xa89\x0e\x81f}"
        b'O\x9c\xcd\xabGg\x1c#\x91\x93>s?\xf1\x16\x94\xe2X\xd3Q\xf6\xa3\xa5g\xb4G\xf0\x8bU\x90=\x1d=\xf2s{\x81\xd6\xa1\x84\xce\xcf\xe8\x07\xe9\x1f\x1c\xdf\x1ck\x83Y\xfc\x94\xe35\x8f\xe3^\x08\xf7\xfe\xfb\x94'
        b"?\xce8%;5\x0f\tz\xfa\xfd9\x99\xab\xf1\x8fWRr\xfb\xfe\xa1\x06\x0cJ\x1f\xa5\xe9\x19)\xba\xecX\xeb\x1a\xaeH\xf6vw\xee1\xfe\x1c\xf0'\xab \xa6h:\x9b\xe8\xd3\x8f\xf6\x1f\xa3\xceX\xc5Kkd"
        b'\xd2\x8b\x12\xc51\xf5\x9b\xab}@\xb7)\xf0\x07\xb0\x96}\x936\x06\xa7R\x03\xf5H\x8e\xa7-"nN\x1ci6\x96\xe3d\xb9\xaea2\xdde\xcf>\x1c\xe5\xf2\xf0\x0b\xd3L\xae\xc18\x94\x12\xa0{\x8e\xf9\x03\x83\xb1'
        b'\x1c_\xc9\x04\xa2\xdc_>[\xe7\xa3\rrK\x03{\xd9f\x8d\x1f\xad\xa5-a\xf2i\x1c\xab\xacQ\xfc\xe8\x14\xcdn\x10\x81\x85\xbf\x05{\xb0\x9e4\xddl\xcb\x1f\xe6\x12\x92\xf58+c\x8f$\x01\xa7\xa5\x1e\x10Y\x0e'
        b'G\x92\xcf\xd8\x92z\xc4i\xe7\x07\x03z\xe1\x92v\xd0P.\xfc\xb6\xc8Nc\xcfJ\x87\x92u\x1b\xa2*q\xac\xbdUA\x11#\x16\xdb\xb3\xbbL\xc0\t\xc5\x0f\xd8\xfe\xbcDkQ\xed\xaa\xb0\xed \xb8T\xc0\xc4)\xf0'
        b'<\xbb\x08\xdb\x83%jV,\xac\xbf|\xf7\x03\xd9\xad\xf1\xcd\xa3F\x9a*v\xc5\x83!\xea\x1b@\xd7\xef\xfa\xb5\xb7\x11\x88\x9dNg\x18\x15./\x84\x00\x92d\xd9\x0f\x1b\x0eh\x04\xbd\x89\xce\xcf5[\xd1K-.\xd0'
        b'\xc7@K\xf0[N\xacJ\x91\x8d9\xb2l\x03\xe1\x92LgB\xa4s\x04\xd0\x96\n\x14\xa1}o\x0b\xba\xc7E\xcb\xd4\x86\x97\xc0\xd8\x0c\xaf\xe4O\xf59\xb93\xc6\xeb4!rKD\x15\\\xd4\xb1\x8f(9%\x1b\x8b'
        b'\x93]@\xba,\xdb\xe7\x17\x8a\x00\xa4:\xba\x0f\x99\xd0\x16\xcb\xebw\x8e$\xac\x15\xe8e\x89\x03t=:.\xe2\x0b\xae\xb0@[\x82\x92`%2\xc8\x0b\x90^\xb2\xf3\x18\x8d\xb6\x11g1\xb1 5\x9f\xb0.\xfc\x95\x04'
        b'f\x13\xfe\x16G\x88>\x0b\x10\xd8\x85\x1eX\xba\x80Q:3\xc4P\xd0"\xf9\xf4-\x7f\x16\xe3\xc9\x10\x9bC\xf6\xae\x8dg\xd6\xb0\x0e\xf4p\n%\xf3D\x0c&\x18\xac\xa3\xda\x0b]#\x04\xf0\xd0\x03,>\xc4\x1chL'
        b'\xe9Th*\x83\xd9\x0f\x10\x1e\xb2\x98\xfa5\xa1#m\xf6\xfb\x9c\x9et\xba\x8f\xa9\xa9\xf6\xeb\xa3\xe4\xf4E\xc5\xa8\x1a\xe0\x07\xcdm\n\x05\x1a\x86L\x94/v\xe2}\x9a\x10\xd5\xd9x\xbb\x19\xc8l;\x06Z\xf1\xbc\xff\xe6'
        b'\xc1\xb7\xb7_\xcb\xe9\xe8\x19\x10&t\x83\x16\xb6\x8d\xec\xa9[\x055\xe7x\rev\xab\xf8\x12_\xa6<\x07\x92c\x90\xe4\xc0\xc41P\x81\xa1\xebH\xf4\x99Dj6Gb\xc2:\xc6S\xe4]\xe26GK\x8dj)'
        b'\xd4\xb8\xb6\xc6O\xef\xff\xfcF\x84\xa4\x11]\xaf\x98Qd\xc7\x80\x81\x0cz\x1f\x15;\xd5\xa5i\xfehb\xd4y\xd0\xbb\xda\x17\xf8\xad\x12\n\x1174\x8e\x00\xea\x92{\xdc\nF\xf3\x0f7S\xe5\xb2h\x8ay\xe2\xa8\xa7'
        b'j\x1c\xb9:.\xa7\xe9l\xc3\xf2T\xc0b\xaa\xc1\x97 \x89\xd2q\xdb\xd1y\xc1L\x1a\x97\xd4\xa1\x1e7\x9a\x88\xf6\xc0]\xa5\xdcJ\xd7:\x8c;1\xb6\xc0J\x8b\x13\xc8\x87{\xa2\xb3\xb3\xe0KA\xd15\xac+=\x92'
        b'\xdaDQ\xd0\x95\xf2\xa9\xf9\xda\xa7\x01\x1c\x88Oac\xaf\xa6\xcb\x87\x86:\xa5r\xba\xbd!\xd1z\xea\nG\x13f8\xae\x1d\xdcft#\xea\x16\x14\x90\xa2$\xd8T\x06\x9b\xcf$\xd2\xf5\xb2[T\xb2U\xf7\xe4\x04\x02'
        b'\t\xb3_\x05\xe6p\xfat\x8f\xecK\x02\xbaU\xee\xec\x07q\xe8\x87\xd1\xb7F\x8d\x02\x18"\xeb2-F\x99\x8fG\x82\x9a\xd2\xc0\xf1\xce\xe37!\xecxNr\x93*\xa9\xf1\xa7l\xa1\xf2\x07\x82d\r\xf3\x9f\x9f\x93\x9b'
        b'\xd0\x12s\xa3EFX\xf6b\xa2~\xa0\x9a~\xc8)Z"\xf1\x16c\xfcV[\x9a!\xc9F\xd0\xe6\xce\x8d\xf6M@s\xd3\x0c\x1b\xd7Z\xd3K\x16\xab\xf7\xaf\x8d9\xdf\xcd\xc1\xb9\x84\xfam\x19v*\xb2\xaf\x86\x18\x0f'
        b'_\x82p\xf3\xcdZ\xa6^\xdc\x1d\xca$\x0c86\xb6\xe8\xfc\x84\xc3m\x08\x00\xad\xd2>\x05\x9c\x13\x9ca\xa99F\xb1\x00\xcaj\x1c\xe9\xac\x00r\xca\xca\xb6]d`D]\xe9\xbd\xd8<`e\xf7%\xf8\x95\x1c\xfa\xd2'
        b'\x15\xed\x91|0:<\\\x84\x87\xe42\xf02\x04"K\x08aj\xd3\xe6#\xd8~\xab\x19\x1b&\x1cr :\x8b\x86\tW\x05!\xfd\xeb\\\x82\x0e\xf3\x1d|c\xba\xa3\xae:"\x94\x08\x98\x8c,Wz3\xb2\xcb\x9d'
        b'\xbe\x01\xceb\x1dY\xa1\xe1"\xcd\x07&\x9f\xc5Ca\x8d\x91\x98N\x83Ae}\xecB\xd5\xba\xdfw\xbc\xde_\xdd\xfa\xcbY\x80EJ\tCx\x9d\xf7\xa8\xb1\xc8\xe7\xf0\xd1\xb8\xb7\xbd\xefo\xa9!,4\xb6\x1a\xc1\x87'
        b'\x17hp\xb9\x1cm\x00{\xdf\xf2{2J\x16\x8e\xc2\xe2\xbcr\xb3/\x0e\x1b>\xc8\x8a\xee\xea\x86\x90\xd7\xc9\x03l\x8b\x8cH\xc1\x0e\xeffX\xea\xbap%/|\xa0\xeb\xe6\x96/\xbaeF \xec\xab\x8f\xaa\xd1\xf7='
        b'\xe9\x96>\x04\xe3\xa2\xda\x18\xba\x92\xf8%\xb1\xd8Q\xf9\x7f\xd7"\xc3\xc2\xbe\xc0\xafT\xe9<p\x11.ZM\xe6E}p\x13\x10\xfd??\xe8\xc7l\x0b\x0f\xaa\xa8\xa5\xf7M\x0f\xf4\x8f\xd7s\x93\xb5\xe1\xfe>\x08>O'
        b'\x92\xeb\x9c\xa9\xa1,\xbc\xe1bv\xc1WT\xa7}\xae\x9d=B\xac\xf4\xa7D\x1e\x17\xfaB\xf3\xa6\x9a|\nT%\xf9y\x1e\xfbM\xe4b"F^\xd8\xc82\xf0\r\x15L\x9eV\xb4\xa7\xbd\xd5}\x9f\x91Pl\x03:'
        b'd\x8b?2\xed\xff\x0fU!W\xca\x1c=4\xdd\x99\x98,\x0e#\xb4\x8f\xdf%\xc5\x05=\xb2\xa50\x9c\xf9\xb6p\xbb\x80\x95\x14c:\xcb{H\x0f\xd4\xa3|\xf3\xcd\xe5\xfaV\xc7\x06\x004\x90u&;\x8eC\x96\xb1'
        b'\xb9ka\x9apu\xc0\x9a\xc1\xd6GKS\xf5^\xb7\xba\xc1\x94\x8fZH\x98ZT9\x83\x114\xfa\x02\xf3\xbf\x94\x84\x02\xd5\xb1\xd0\r\x1dt\x86\x86\xec8\xc3\x8cK\xa8.[\xafN\x025\x8a(~\xb0CF\xdfJ'
        b'\x83\x1f\x16\xa9\x8c\xefs3c\xf4\x0b\xcd\xb6F46\xf3\xc7\x9b`\xdbXP21\xdf\xa9\xe2\xb0lk\xc5\x174\x97\x99W\xc3\x02yB\xd0/c\xe0\x9a\x0c\xb2#l\xa7;\xb3\x844[\xa7\xc3+\x0c\x9b\xe0\x97\x02'
        b'^|{0\xf8z\xc7\x07\xc2Q1W\x85\xc7x\xd2\xde\xff\xbb\x02\xf9\x00k5f\x16Ll\xc93\xa8\xca\xea\x07D\x1bZu\xbf\xb6*X\xee\xaa\xc8\x11\xb3\xdb\x87{\x16\x15-\x8f\xd6\x1b\x0fI\x07\xb9Ya\x8d\x01'
        b'<R\x9f\x06d\xae\xa7\xcb5\x8e]\xef\xda\xb9\xc9\xbfR\xa7\x85\'\xd5\x0ea\\\xc7\xe5\xb3\xcb\x9b\xdb\xcb\x01l8?er\x8e\x06\xa0\xdf\x8cQ-`"p\x94\xcc\x8bU_\xb5\xc8B\xff\xc9\xf2X\x19\xfd9\x16\xd0'
        b'\xb2\xfc\xaf\xa9a*\xd1\xa9!]\xfeR4\xda\x13\xe1\xc8\x95ma\xf3\n\xb4*g\xb1E#\xc7\x7f\x14\xdc\xecs>7b(O\x1b\xc7\xd1,\xbcg\x96\x9a\xde>xx\x1f%\xa2E_\xb2f\xee;\xbf\xde\x9b\xaa'
        b'\xa451\x06\x0c\x94\xac4\xc8\xeb\xff\x15x6OP\x01\xbfP\x087\xd0\x96\x85\xdc\xdf0\xfb\x1f\xca\x08\xb0\xc8\x1d\xd9\xf4\xf5\x06\x03\x1d\x9ded\xfcxX\x0c\xacR\x99\xf7\x1fD\xc5k#=\xbb\x1c\xd5\xcf\xfd\xd1w'
        b'\x0c\x88l\xd9T\x90Z\xd1\xe5\x981\xe8Ld|@\xf7\xc9Y\x05"xc0v9x #4\'\x03\xf7\xfat\x86\x8akBv\xeb\xdbs\xa7\x99s\x14\xfd\xb2\x88\x1eM\x1a\x93D-\x8a\x86\xd6\xfdT\x15}^'
        b'\x1a\x81,Nz=\x96\xbdi\xc7\x1b\xa7\x1d\xa4\xd3\x97{\x7fi7\xd0\xbf\x8e\x82\xa3\xd9:\x96\xd7\x05\xbf)\x05vK_\xc4\x95\xc4C$\xef]\x03\xe3\xb1I\x12\xf2\x90*G\xf9`\x03\xbe\x05\xc1\xfb\xd8\xcd\xfbHS'
        b'\xb8O\xade~W\xfe\x92c\xb6<X\x12\xec\xe2T\x99\xa7\xef\x835\xf4q\x8b\xf69\xd6]\x83\xc0F\xd9l\xd6|\x18\xad]\xe1\r\xbaP u=:{\x8a$\xb8\xb1?\xe9\xb3\xff\\\xba\xf3\x86\xac.)\ny'
        b'\xc1\xa1\x0ew\xa8\xc6\x0f\x08\xd2\x8e\xffM=%\xd5\xc2\\\x8f\xac\x17\xc5\xb2_q\x10})m!*\xac\xfc;VU;{\xdeu\xcd\xc8\xce\xcc\xc5\xe1\xb0h\xf6\xc9\x08l+BTR\xe8\x1aq\xfan#[\x94\xa1'
        b'n\xa6f\xc5\xd2\xe6I\xc2\xf6\xf7c-\xeb\xa8M\xfa\x85\xa9\xe3;\xcf\x02\xec\x81\x9a\xf8\x08\x88\xcbc\x9fYh\xf9\xaf\xba\xee<\x85=\x0b\x93\xd8\x1f\x00\x91\xe5h\xc2-y\x8f\xb4\xca`e\x07\x9d\x8f\xf7\x19\xe7\x8e\x9c'
        b'\xc6L\x84\x87/\xf5\xc7\x87\xfc5\xa0\xbb\xe5\xb7\xc1"\x8f\xed\xbeb}\x9b\xe3&Z=>\xe6N\x16\xad\xf2A\xd3q\\k\xc3<\x85(\x11\x13\xbd\x10]\x1f\xed\x88X\x04\xa9\xc1KO\x83\xf1\x0cE\x06\xdar0\xad'
        b'\x90)\x8c\xaa\x8d1\xbf\xf8\xd6<\xe6\xe4\xca\\\xdb\xf0\xcfO^^\x1c\xec\xa8\xdb\xd8\xa0\xeb\xf5\xe5\xb8H\x95*N\xb3\xd9^(\x87\xc5\x0b\xeaX&qf\xba\xd4\x8eDbF%dD\x96\xd20\x8f\x86\xe3@j\xb4'
        b'\xe7\x12]\xdb\x1b\xed\xcf\xaeOI\x93\xa3\x8c@$Nb\xc7 M\xbb\x07ZA>UE\x9b\xe9\x9e\xa0aY\xf94\r\xf8\x05\x05\xea\xb1\xbe\xa21\x12\x9dFj\xd8\x08_\x008\xfc\x1a\xc2\x95J^\x08\xb1\x0fKc'
        b';\xd7\xe8\xa3\xc3Q\x134L\xf8wv}\xdfU\xdf\xb6\x8d\xc3%\xbfau\xd0\xc8:\xedlZ\n\xe9glq\xc6*\xd1\xc5\xfal^\xd9I\xeeXC-\x9146^C\xf0Jy\xdc\x1d\x8bb\x91\xa7\xec6r'
        b'RJ\xe3<_\xdd\xf3I)\xdc2\x9a\x9au\x18\xf17\x1f\xf8\xabcf\xa1\x89\xb7f\xcd\xba\xdb\xe1\x06\xeb\x82\xf8nY\xe9\xe3\xef\x94P\xcd\xfc`M\xee\x99\x06}\x7f\xbd,7c\x1b\xadgO\xb3(X/=\xf2'
        b'\xb0@\x84+=\xddY\x8c}aa\xaao]\xac\xfa\x04\xac[&\x87nC\xa0\xb3\xc3\xf8h\t\xf1\x0ca\xe6\x18]\xe0\xed.\xd3s\x8c\xb1\xfd\x9f\x02c\xad4\xd5\xaf\xaa\x8c\xb6\x87\xe5I^p{\xa9S\xc37\x8a'
        b'\xab{|\x1f\xb7N\x9b(i\x0e\xc6\xb6\xe4\xfd&>\x18U7\xc1r^\xbc\xe9\xf8\xe9\x03\x99\x19e\x16(\x93!\x06\xbe\xcc\x1e\x13\xde\xc0{BGQ\xb5=\xc6\xd3\xb3\xed\x8cNU\x19[\xbeD\x15\xcd\xe1e\xcb/'
        b's\x9c\xb7\xd5b\x0e\xf43\xa8h=\xb7\x9a\xfc\x89#\rYrK-\xeeC\x9b\xd1B\x91\xf0\xdc\x02b\xf5\x01\xa1\xbf(%l\xa0\xca\x06A\x04\x9f\xce7n\xf0,>\xb4\xdf\x7f\xb0\x90\x1e\xdf\t\xbc\x81\x12\xc0\xc61'
        b'\xee\xea\xdc\x8c&\x0c\xd4\xa8\xb5\x0f%\xcb\xdfWt\xb94\xbc7x\xf8)\t\xecmX\x80\xbfb\xcf\xae\x03\x9d\xafs\xbb\xe6\x8a\xa2^\xca\xf3\x0b\x19A\xbd\xe6*\x1e\xfd\x81h\x12\x80\xfe\x9aX\xac\xc44qs\xd3\x99'
        b'FJ\x9e?\xb6\x92\xf4\x1d@\xa3|>\x012\xfee%\xa9[\x9cre\x82\xca\x89\xeb\xbby"\x9au\xb1\xe9-S\xbd\x03f\n\xa7k\xd8\x80\xc5%\x10e\xa7\xa7\xe2b\xe61\r\xd0\xab\xb0\xff\x86\x8f\xc3\x00\xc1\xfe'
        b'\x97f\xbf>\x8f\x9b:\xda faC\xda\xc1)\x1b\n\x1e\xb6\x03\xd4\xbc\xc81\x10\xb0g\xfcV\xe8G\xb1\x83\x0bT8\xd5\xf4\xd8\xec|<\xdc\xc39\x19\xaeY\xf2N\xd6\xba\xe0\xbf\xd59\xc0!\xff\xea:\xd9\x0c\xb7'
        b'\xc4\x1f)\x9d\xfe(\xbb\x8f\x8e\x89\x0fE+\xf9y~\x19)5^\x11H\xdcf}\xd9\xf7\xce\x85\x10!\xe8MO6*\xaa8\xdeW\xa8\xdao\xac*\xe4\xcd\xd3\xfc\xe71D\xcb\x97ki\x83\x93\x18\xe2\x97\xd2}c'
        b'z \x84\xf0C{{\xab\x83+a\xed*\xb8D\xce\xe2\xcc\xd2o\x9c\xa1\xe7/\x06\xdf\x83\xd3\xefTDt6 9]K\xb6\x16\xcd\xe4d\xfb\xb7%\xeedS\xfc\x10\xb3\x045^\xb9\x1dWL\x05!29\x00\xe5'
        b"\x00\x00\xaf\xceP\x97|\xc0\xf1\xc6[\x80\x1e\x11\x93\x1d'h\xba\x1f\xb5Y\xc8&3\xca\xe2\x16\x9f\x01\xb3es\xd0\xa7S\xdd\x10^\x1be\xbb\xf2\xe7\x9dc\xc2n\xb1\xa9{\xe7\xa9f\xa8\xfd\xf7P\xc6\x19\xed\xa6=\xc4"
        b'\xb1\x97\xf5\xce=Ug\xe6\xeegq\x99\xbd\xc1\xdbSC\xfb(j\xd9La\x82OI\xe0\x02\xcf\x04\xa0\xeb\xb5b\xa2\x1f} \xc8\x10\xe8\xf2\xeb\x0e\xc1\xca\x8e\xa5\x86\x98\xe1s)\xb0\x8f\x13\x89R\x7f\x03\xdc\r\xdd\xe5'
        b'\x18\xc6\xdc\xed\x9f~\x90^\xd5\x11Av\x14\x85\xe43I\x1d\x8f\x90[\xc2\x84H\xf2%\x9e8)"\xf6\xe0\xc7\xca\xa0\xfb\xa8I\xfdOjq&\x88\xb2\x12\x99\x0cc\xa6\xabR\'\xe7\xd2\x12\x16\xc5\xe7\xef\xef\x88R\x8e'
        b'\x15Z>\x86\xd4\x11\xc2oi\xd5\xef\xd3+0@\xce\xc6H\xa1\r\xe1\x80\xf3\xa5\xf0{\x04C\x07\xd0\xdc\xba;^8\xf2K\xdcJ\x01E\xd4D\xa8\xb8T\xa7<\x7fz%VZ\xdd\x16u\xfc\xf8r+\x9a\xbaP\x82'
        b'\x07\xfc\xd5I\xa7|\'a6k\xe2\x1c\xd3\xd3\x1e\xf2\x147S\x86\xd7\xaa\xc8\x94\xbb\xdf\xb98\x8cIe\x89"\xc3C\x7f\xd6\x1cK\x80\xc3\xca\xedc=\x84\xc4\x9a\xab\x1d\xe9I\xe5a/\x1bW\x03p2+\x03\x13O'
        b"\xc3\x93\xa2\xf9NC\xa78\xfe[\xb7.ze\xb2\x93\xb3^\xfbo\x94\xbb\xae\xb4Q\xef/y'|\xf2h\xf7c\xfd\x9eI~\xaf\xfaD\xcf~\xca\xd6^w\x01\x06\xe6\x95\x8c\xdd\xf3c\xd3x\xf4\xc0\r<\x89\xa7\x96"
        b"\xc0\x82L\n\x87#\xae\xa7v\x06\xd7Ha\xa1C\x07\xce\x01\xa4\xecYGU\x8d\x9f\x89s\x01\xed\xda`\xe1~\xf8\xaa\x83\xd2;,\xe2\xd8\x1f\xb9\x01'\xe3\x17\x02\xbaI\x1f:\xd1V\xd2\x9f\x9f\x00\x9f\r\xaeZ\xc8\xc3"
        b'\xff\xc2\xbbfnr\x1e\xb5QP]\xe49\x8d\xc4\x17\xacX\x05\xdcH\xe2no\xe7\xcc1\xd9\xee\xcc\x01A\x02<VuO\xe6@\x01\xb6\xc4t\x0b\x9d\xd0a\x19\xb3V\x15\xb0\x8f7L\xb4\xe2\x01{\xcb\x03\xf2)&'
        b'\xaeq\x97\xf4\x06\x13^\xf5 J\xfc\x99\xf1\xf9\xeb\xb3\x91\xdf\xae\xb4\x8c\x10w\xd7\xa4\xd1\xc1|\xfa\x0c\xa6j\n\xe01\xc2\xef\x051)\x9a\x8e\xc4\xe3;Ci\xf1c\xcc\xb6\xfe+u\xe4V\x8b\xb3a\x07Xme\xad'
        b'\x12\x83:\xdd\xc7\xdd\xb0\x80\xe4\xb0k\xaaT\x07\x08&j\xad\xba\x97\xd8Tn\x12O>4&\x8d\xb0\x14\xfe4\x03\xc7\xd3\x01!\x8b[\x06\x8fD\xf2\x812\xa3\xe8\x18&\x83k\xe0\xa5\x11\x0e\x98\x13\x85\xcch\xac\x88\xe9'
        b'g\xab\xa5\xbe\xae\x93R\xd30\xca\xf4\x18m\x11\x0e\xcf\xe3\x18\xe2\xb9Gkb\xc7\x83\xef\xac*\x00\t\xd8\xc5\x08\r\xb7\xbd\xbcY\xff|\xaa\xac\xdbPL\x87\xa1\x8al\xdb\xd6\xa4\xbfEH\x86AP\x007\x1cO\xeb\xe3'
        b'\x19.\xe1\xa4wC\x02$\xfe\xa8\xc2\xd7\xf1\xa6lh\x1b\x86\x0f\x1bzA~V^>P\xbdgQ\xa9KD\xca\x1f\xcf\xae}1&\xb3\x0e<\xd5@\xba\xab/\xbb\x8b\x18z>\\^\x99\x1bg\x0ev\xe6`\x0e\x8f'
        b"jn\rt\xc3p\xaa%\x16n!\xe5\x00\xefO'M|\xf9\t\x02U\xb4\xe8\xf5\xb0\xba\x0cvU\x19\xbb\\\xe4\x97\xc2\xd1\x12\xaf\x14\x92\xe3\x86\xce\xf3t\xc6\xdb\x0b8-\xe8@7\x08\xa0e@a(\xe0\xb8;\xa1"
        b'\xe8\x12\x1c\xff"\xbfj,HI\xd5\xda\xacN\xae\xe8\xb5\xcc\xfbi[\xa2\x06\xcf\x87\x1emh\xd10\x12\xc2J\nU\x98t4sxXu*\x8a\xa7\xe4\xb0!\xe1\xb0\xa5\x80\xe9\x97\xc2\xd73\x8aY\x02\x9fS*\xf9'
        b'=}\xca\xad"\xd6\x88\xe7\x1c\xf4!\xaf\x91m\x8b\xd1m\xff:y\x7f?y\xfb\xe3\xbf\x0b\xd0\xf7-\x19Z\x1a\xeb\x05\x87\x02\x8d\xdc$\x01\xbf\xb7\xc1\xddPZ\xa1\xb7\x19F6\x0b\xb9\x83f:\x15\xeb\xab*w\x19B'
        b"V\xdb$\xd0\x06\xab\x95'=\\\xa0\xcb\xf0+\x04\xf8\xf2\xa8fD\x0c\xf9\x14d\x96<\x9a\xee\xe1l\xf8\xa8\xdf\xe8V\xf3\xdf[7\xf7_\x92B\xe0\x9f\xffB\xbb\x8bH\x96:\xd2\xe3^\x7f\xc6\xb5\x98\x94\xfe\xdf[\xcc"
        b'b\x9a<\xfaKR\x94\xe2"\x18\x12Wi\xca\xde\xaf\xf9\xcal\xdey\x81\x93\x9b\'K\xf6K\xfeY\xad\xfa)\xd6\t\x17\xcd7/\xd3\xd9T\xcb5HC\x84 \xb8\xce\x85\xafy@\xda\xf5;\xbbC\x03\x90\xad.W'
        b'\x85\xb95\x8a\x82\xe32\xdb\xb6b^\xa49\x92\xa8w\x15g\xc5)!\xf3\xc1\xe9\x83\x81\x1a\x04\x81\xe4\xf7K\xfc\x0b\x8e\xfbO\xd9\xa1s?\x99\x7fh\xed\x97\xf2vR=\x91a\x1dT>\xaf\xcfT\xd5\x93x\x00\x1aX'
        b'SL\xf61\xe2\xb647\x8d]~\xf9l\x98+\xde\xfd2u\xf7\xc5\x90\xd5y9\xd9\xe6\x80&\x9d\x19h\xc7re\x17\xea\x82\xba\x8d\x83\x92\x00\x18)\xee4\x1c\x08N\xabb\xf1\xa2\xd3\xd5\xd6\x1a\x82\xa1U\xa3jK'
        b'\x1aM\xce+\xf45\xc1\xc0\xb2\xf1\xca?\x1dX\xaf\xf4s+[\xb9\xfe\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name'
        b'__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08'
        b'\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
